@@ -8,9 +8,9 @@
 
 # Package name      : perl5
 # Source directory  : .
-# Configuration time: Wed Apr 21 19:21:41 BST 2004
-# Configured by     : yourname
-# Target system     : linux bagpuss.unfortu.net 2.4.19-rmk4 #3 fri oct 25 21:57:55 bst 2002 armv4l unknown 
+# Configuration time: Fri Aug  1 15:15:51 EEST 2003
+# Configured by     : jhi
+# Target system     : osf1 kosh.hut.fi v5.1 2650 alpha 
 
 Author=''
 Date='$Date'
@@ -28,7 +28,7 @@ _exe=''
 _o='.o'
 afs='false'
 afsroot='/afs'
-alignbytes='4'
+alignbytes='8'
 ansi2knr=''
 aphostname=''
 api_revision='5'
@@ -36,10 +36,10 @@ api_subversion='0'
 api_version='8'
 api_versionstring='5.8.0'
 ar='ar'
-archlib='/opt/perl/lib/5.8.4/armv4l-linux'
-archlibexp='/opt/perl/lib/5.8.4/armv4l-linux'
+archlib='/opt/perl/lib/5.9.0/alpha-dec_osf'
+archlibexp='/opt/perl/lib/5.9.0/alpha-dec_osf'
 archname64=''
-archname='armv4l-linux'
+archname='alpha-dec_osf'
 archobjs=''
 asctime_r_proto='0'
 awk='awk'
@@ -49,21 +49,21 @@ bin='/opt/perl/bin'
 binexp='/opt/perl/bin'
 bison='bison'
 byacc='byacc'
-byteorder='1234'
-c=''
+byteorder='12345678'
+c='\c'
 castflags='0'
 cat='cat'
 cc='cc'
-cccdlflags='-fpic'
-ccdlflags='-Wl,-E'
-ccflags='-fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
-ccflags_uselargefiles='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
-ccname='gcc'
-ccsymbols='__APCS_32__=1 __ARM_ARCH_3__=1 __CHAR_UNSIGNED__=1 __GNUC_MINOR__=95 __arm__=1 __linux=1 __linux__=1 __unix=1 __unix__=1 cpu=arm machine=arm system=posix system=unix'
-ccversion=''
-cf_by='yourname'
+cccdlflags=' '
+ccdlflags='  -Wl,-rpath,/opt/perl/lib/5.9.0/alpha-dec_osf/CORE'
+ccflags='-std -D_INTRINSICS -fprm d -ieee -DLANGUAGE_C'
+ccflags_uselargefiles=''
+ccname='cc'
+ccsymbols='__alpha=1 __ALPHA=1 __Alpha_AXP=1 __arch64__=1 __DATE__="Aug __DECC=1 __DECC_MODE_RELAXED=1 __DECC_VER=60590011 __digital__=1 __IEEE_FLOAT=1 __INITIAL_POINTER_SIZE=0 __LANGUAGE_C__=1 __osf__=1 __PRAGMA_ENVIRONMENT=1 __STDC__=0 __STDC_HOSTED__=1 __STDC_VERSION__=199901L __TIME__="15:16:43" __unix__=1 __X_FLOAT=1 _LONGLONG=1 _SYSTYPE_BSD=1'
+ccversion='V6.5-011'
+cf_by='jhi'
 cf_email='yourname@yourhost.yourplace.com'
-cf_time='Wed Apr 21 19:21:41 BST 2004'
+cf_time='Fri Aug  1 15:15:51 EEST 2003'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -76,19 +76,19 @@ cp='cp'
 cpio=''
 cpp='cpp'
 cpp_stuff='42'
-cppccsymbols='__ELF__=1 __GNUC__=2 linux=1 unix=1'
-cppflags='-fno-strict-aliasing -I/usr/local/include'
+cppccsymbols=''
+cppflags='-std -D_INTRINSICS -fprm d -ieee -DLANGUAGE_C'
 cpplast='-'
 cppminus='-'
 cpprun='cc -E'
 cppstdin='cc -E'
-cppsymbols='_FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=2 __GNUC_MINOR__=95 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=199506 _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __linux=1 __linux__=1 __unix=1 __unix__=1'
+cppsymbols='_AES_SOURCE=1 __alpha=1 __ALPHA=1 _ANSI_C_SOURCE=1 _INTRINSICS=1 LANGUAGE_C=1 __LANGUAGE_C__=1 _LONGLONG=1 __osf__=1 _OSF_SOURCE=1 _POSIX_C_SOURCE=199506 _POSIX_SOURCE=1 __STDC__=1 _SYSTYPE_BSD=1 __unix__=1 _XOPEN_SOURCE=400'
 crypt_r_proto='0'
 cryptlib=''
 csh='csh'
 ctermid_r_proto='0'
 ctime_r_proto='0'
-d_Gconvert='gcvt((x),(n),(b))'
+d_Gconvert='sprintf((b),"%.*g",(n),(x))'
 d_PRIEUldbl='define'
 d_PRIFUldbl='define'
 d_PRIGUldbl='define'
@@ -110,15 +110,15 @@ d_alarm='define'
 d_archlib='define'
 d_asctime_r='undef'
 d_atolf='undef'
-d_atoll='define'
-d_attribut='define'
+d_atoll='undef'
+d_attribut='undef'
 d_bcmp='define'
 d_bcopy='define'
 d_bsd='undef'
 d_bsdgetpgrp='undef'
-d_bsdsetpgrp='undef'
+d_bsdsetpgrp='define'
 d_bzero='define'
-d_casti32='define'
+d_casti32='undef'
 d_castneg='define'
 d_charvspr='undef'
 d_chown='define'
@@ -136,10 +136,10 @@ d_ctermid_r='undef'
 d_ctime_r='undef'
 d_cuserid='define'
 d_dbl_dig='define'
-d_dbminitproto='define'
+d_dbminitproto='undef'
 d_difftime='define'
 d_dirfd='define'
-d_dirnamlen='undef'
+d_dirnamlen='define'
 d_dlerror='define'
 d_dlopen='define'
 d_dlsymun='undef'
@@ -170,15 +170,15 @@ d_fcntl='define'
 d_fcntl_can_lock='define'
 d_fd_macros='define'
 d_fd_set='define'
-d_fds_bits='undef'
+d_fds_bits='define'
 d_fgetpos='define'
 d_finite='define'
 d_finitel='define'
 d_flexfnam='define'
 d_flock='define'
-d_flockproto='define'
+d_flockproto='undef'
 d_fork='define'
-d_fp_class='undef'
+d_fp_class='define'
 d_fpathconf='define'
 d_fpclass='undef'
 d_fpclassify='undef'
@@ -195,7 +195,7 @@ d_ftello='define'
 d_ftime='undef'
 d_getcwd='define'
 d_getespwnam='undef'
-d_getfsstat='undef'
+d_getfsstat='define'
 d_getgrent='define'
 d_getgrent_r='undef'
 d_getgrgid_r='undef'
@@ -213,7 +213,7 @@ d_getitimer='define'
 d_getlogin='define'
 d_getlogin_r='undef'
 d_getmnt='undef'
-d_getmntent='define'
+d_getmntent='undef'
 d_getnbyaddr='define'
 d_getnbyname='define'
 d_getnent='define'
@@ -246,13 +246,13 @@ d_getservbyname_r='undef'
 d_getservbyport_r='undef'
 d_getservent_r='undef'
 d_getservprotos='define'
-d_getspnam='define'
+d_getspnam='undef'
 d_getspnam_r='undef'
 d_gettimeod='define'
 d_gmtime_r='undef'
-d_gnulibc='define'
+d_gnulibc='undef'
 d_grpasswd='define'
-d_hasmntopt='define'
+d_hasmntopt='undef'
 d_htonl='define'
 d_ilogbl='define'
 d_index='undef'
@@ -260,7 +260,7 @@ d_inetaton='define'
 d_int64_t='define'
 d_isascii='define'
 d_isfinite='undef'
-d_isinf='define'
+d_isinf='undef'
 d_isnan='define'
 d_isnanl='define'
 d_killpg='define'
@@ -287,7 +287,7 @@ d_mkdir='define'
 d_mkdtemp='define'
 d_mkfifo='define'
 d_mkstemp='define'
-d_mkstemps='undef'
+d_mkstemps='define'
 d_mktime='define'
 d_mmap='define'
 d_modfl='define'
@@ -299,7 +299,7 @@ d_msg_ctrunc='define'
 d_msg_dontroute='define'
 d_msg_oob='define'
 d_msg_peek='define'
-d_msg_proxy='define'
+d_msg_proxy='undef'
 d_msgctl='define'
 d_msgget='define'
 d_msghdr_s='define'
@@ -310,7 +310,7 @@ d_munmap='define'
 d_mymalloc='undef'
 d_nice='define'
 d_nl_langinfo='define'
-d_nv_preserves_uv='define'
+d_nv_preserves_uv='undef'
 d_off64_t='undef'
 d_old_pthread_create_joinable='undef'
 d_oldpthreads='undef'
@@ -323,19 +323,19 @@ d_phostname='undef'
 d_pipe='define'
 d_poll='define'
 d_portable='define'
-d_procselfexe='define'
+d_procselfexe='undef'
 d_pthread_atfork='undef'
-d_pthread_attr_setscope='define'
+d_pthread_attr_setscope='undef'
 d_pthread_yield='undef'
 d_pwage='undef'
 d_pwchange='undef'
 d_pwclass='undef'
-d_pwcomment='undef'
+d_pwcomment='define'
 d_pwexpire='undef'
 d_pwgecos='define'
 d_pwpasswd='define'
-d_pwquota='undef'
-d_qgcvt='define'
+d_pwquota='define'
+d_qgcvt='undef'
 d_quad='define'
 d_random_r='undef'
 d_readdir64_r='undef'
@@ -352,7 +352,7 @@ d_safemcpy='undef'
 d_sanemcmp='define'
 d_sbrkproto='define'
 d_scalbnl='define'
-d_sched_yield='define'
+d_sched_yield='undef'
 d_scm_rights='define'
 d_seekdir='define'
 d_select='define'
@@ -386,11 +386,11 @@ d_setprotoent_r='undef'
 d_setpwent='define'
 d_setpwent_r='undef'
 d_setregid='define'
-d_setresgid='define'
-d_setresuid='define'
+d_setresgid='undef'
+d_setresuid='undef'
 d_setreuid='define'
-d_setrgid='undef'
-d_setruid='undef'
+d_setrgid='define'
+d_setruid='define'
 d_setsent='define'
 d_setservent_r='undef'
 d_setsid='define'
@@ -408,7 +408,7 @@ d_sigsetjmp='define'
 d_sockatmark='define'
 d_sockatmarkproto='undef'
 d_socket='define'
-d_socklen_t='define'
+d_socklen_t='undef'
 d_sockpair='define'
 d_socks5_init='undef'
 d_sqrtl='define'
@@ -417,14 +417,14 @@ d_srandom_r='undef'
 d_sresgproto='undef'
 d_sresuproto='undef'
 d_statblks='define'
-d_statfs_f_flags='undef'
+d_statfs_f_flags='define'
 d_statfs_s='define'
 d_statvfs='define'
-d_stdio_cnt_lval='undef'
+d_stdio_cnt_lval='define'
 d_stdio_ptr_lval='define'
-d_stdio_ptr_lval_nochange_cnt='undef'
-d_stdio_ptr_lval_sets_cnt='define'
-d_stdio_stream_array='undef'
+d_stdio_ptr_lval_nochange_cnt='define'
+d_stdio_ptr_lval_sets_cnt='undef'
+d_stdio_stream_array='define'
 d_stdiobase='define'
 d_stdstdio='define'
 d_strchr='define'
@@ -437,11 +437,11 @@ d_strftime='define'
 d_strtod='define'
 d_strtol='define'
 d_strtold='define'
-d_strtoll='define'
-d_strtoq='define'
+d_strtoll='undef'
+d_strtoq='undef'
 d_strtoul='define'
-d_strtoull='define'
-d_strtouq='define'
+d_strtoull='undef'
+d_strtouq='undef'
 d_strxfrm='define'
 d_suidsafe='undef'
 d_symlink='define'
@@ -463,12 +463,12 @@ d_tmpnam_r='undef'
 d_truncate='define'
 d_ttyname_r='undef'
 d_tzname='define'
-d_u32align='undef'
+d_u32align='define'
 d_ualarm='define'
 d_umask='define'
 d_uname='define'
 d_union_semun='undef'
-d_unordered='undef'
+d_unordered='define'
 d_usleep='define'
 d_usleepproto='define'
 d_ustat='define'
@@ -491,9 +491,9 @@ d_xenix='undef'
 date='date'
 db_hashtype='u_int32_t'
 db_prefixtype='size_t'
-db_version_major='4'
+db_version_major='1'
 db_version_minor='0'
-db_version_patch='14'
+db_version_patch='0'
 defvoidused='15'
 direntrytype='struct dirent'
 dlext='so'
@@ -501,7 +501,7 @@ dlsrc='dl_dlopen.xs'
 doublesize='8'
 drand01='drand48()'
 drand48_r_proto='0'
-dynamic_ext='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
+dynamic_ext='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 eagain='EAGAIN'
 ebcdic='undef'
 echo='echo'
@@ -516,23 +516,23 @@ endservent_r_proto='0'
 eunicefix=':'
 exe_ext=''
 expr='expr'
-extensions='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared Errno'
+extensions='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared Errno'
 extras=''
 fflushNULL='define'
 fflushall='undef'
 find=''
 firstmakefile='makefile'
 flex=''
-fpossize='16'
+fpossize='8'
 fpostype='fpos_t'
 freetype='void'
 from=':'
 full_ar='/usr/bin/ar'
-full_csh='/bin/csh'
-full_sed='/bin/sed'
+full_csh='/usr/bin/csh'
+full_sed='/usr/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='2.95.4 20010319 (Debian prerelease)'
+gccversion=''
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -553,14 +553,14 @@ getservbyname_r_proto='0'
 getservbyport_r_proto='0'
 getservent_r_proto='0'
 getspnam_r_proto='0'
-gidformat='"lu"'
+gidformat='"u"'
 gidsign='1'
 gidsize='4'
 gidtype='gid_t'
-glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
+glibpth='/usr/shlib /usr/ccs/lib /usr/lib/cmplrs/cc /usr/lib /usr/local/lib /var/shlib'
 gmake='gmake'
 gmtime_r_proto='0'
-gnulibc_version='2.2.5'
+gnulibc_version=''
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -576,9 +576,9 @@ html3direxp=''
 i16size='2'
 i16type='short'
 i32size='4'
-i32type='long'
+i32type='int'
 i64size='8'
-i64type='long long'
+i64type='long'
 i8size='1'
 i8type='char'
 i_arpainet='define'
@@ -591,9 +591,9 @@ i_dld='undef'
 i_dlfcn='define'
 i_fcntl='undef'
 i_float='define'
-i_fp='undef'
-i_fp_class='undef'
-i_gdbm='define'
+i_fp='define'
+i_fp_class='define'
+i_gdbm='undef'
 i_grp='define'
 i_ieeefp='undef'
 i_inttypes='define'
@@ -605,27 +605,27 @@ i_machcthr='undef'
 i_malloc='define'
 i_math='define'
 i_memory='undef'
-i_mntent='define'
-i_ndbm='undef'
+i_mntent='undef'
+i_ndbm='define'
 i_netdb='define'
 i_neterrno='undef'
 i_netinettcp='define'
 i_niin='define'
 i_poll='define'
-i_prot='undef'
+i_prot='define'
 i_pthread='define'
 i_pwd='define'
 i_rpcsvcdbm='undef'
-i_sfio='define'
+i_sfio='undef'
 i_sgtty='undef'
-i_shadow='define'
+i_shadow='undef'
 i_socks='undef'
 i_stdarg='define'
 i_stddef='define'
 i_stdlib='define'
 i_string='define'
 i_sunmath='undef'
-i_sysaccess='undef'
+i_sysaccess='define'
 i_sysdir='define'
 i_sysfile='define'
 i_sysfilio='undef'
@@ -633,16 +633,16 @@ i_sysin='undef'
 i_sysioctl='define'
 i_syslog='define'
 i_sysmman='define'
-i_sysmode='undef'
+i_sysmode='define'
 i_sysmount='define'
 i_sysndir='undef'
 i_sysparam='define'
 i_sysresrc='define'
-i_syssecrt='undef'
+i_syssecrt='define'
 i_sysselct='define'
 i_syssockio='undef'
 i_sysstat='define'
-i_sysstatfs='define'
+i_sysstatfs='undef'
 i_sysstatvfs='define'
 i_systime='define'
 i_systimek='undef'
@@ -651,11 +651,11 @@ i_systypes='define'
 i_sysuio='define'
 i_sysun='define'
 i_sysutsname='define'
-i_sysvfs='define'
+i_sysvfs='undef'
 i_syswait='define'
 i_termio='undef'
 i_termios='define'
-i_time='define'
+i_time='undef'
 i_unistd='define'
 i_ustat='define'
 i_utime='define'
@@ -663,12 +663,12 @@ i_values='define'
 i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
-ignore_versioned_solibs='y'
-inc_version_list=' '
+ignore_versioned_solibs=''
+inc_version_list=''
 inc_version_list_init='0'
 incpath=''
 inews=''
-installarchlib='/opt/perl/lib/5.8.4/armv4l-linux'
+installarchlib='/opt/perl/lib/5.9.0/alpha-dec_osf'
 installbin='/opt/perl/bin'
 installhtml1dir=''
 installhtml3dir=''
@@ -676,13 +676,13 @@ installman1dir='/opt/perl/man/man1'
 installman3dir='/opt/perl/man/man3'
 installprefix='/opt/perl'
 installprefixexp='/opt/perl'
-installprivlib='/opt/perl/lib/5.8.4'
+installprivlib='/opt/perl/lib/5.9.0'
 installscript='/opt/perl/bin'
-installsitearch='/opt/perl/lib/site_perl/5.8.4/armv4l-linux'
+installsitearch='/opt/perl/lib/site_perl/5.9.0/alpha-dec_osf'
 installsitebin='/opt/perl/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
-installsitelib='/opt/perl/lib/site_perl/5.8.4'
+installsitelib='/opt/perl/lib/site_perl/5.9.0'
 installsiteman1dir='/opt/perl/man/man1'
 installsiteman3dir='/opt/perl/man/man3'
 installsitescript='/opt/perl/bin'
@@ -697,40 +697,40 @@ installvendorman1dir=''
 installvendorman3dir=''
 installvendorscript=''
 intsize='4'
-issymlink='/usr/bin/test -h'
+issymlink='test -h'
 ivdformat='"ld"'
-ivsize='4'
+ivsize='8'
 ivtype='long'
 known_extensions='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Thread Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 ksh=''
-ld='cc'
-lddlflags='-shared -L/usr/local/lib'
+ld='ld'
+lddlflags='-shared -expect_unresolved "*" -O4 -msym -std -s -L/usr/local/lib'
 ldflags=' -L/usr/local/lib'
 ldflags_uselargefiles=''
 ldlibpthname='LD_LIBRARY_PATH'
 less='less'
 lib_ext='.a'
-libc='/lib/libc-2.2.5.so'
-libperl='libperl.a'
-libpth='/usr/local/lib /lib /usr/lib'
-libs='-lnsl -lgdbm -ldbm -ldb -ldl -lm -lcrypt -lutil -lc'
-libsdirs=' /usr/lib'
-libsfiles=' libsfio.so libnsl.so libgdbm.so libdbm.so libdb.so libdl.so libm.so libcrypt.so libutil.so libc.so'
-libsfound=' /usr/lib/libsfio.so /usr/lib/libnsl.so /usr/lib/libgdbm.so /usr/lib/libdbm.so /usr/lib/libdb.so /usr/lib/libdl.so /usr/lib/libm.so /usr/lib/libcrypt.so /usr/lib/libutil.so /usr/lib/libc.so'
-libspath=' /usr/local/lib /lib /usr/lib'
-libswanted='sfio socket bind inet nsl nm ndbm gdbm dbm db malloc dl dld ld sun m crypt sec util c cposix posix ucb BSD'
+libc='/usr/shlib/libc.so'
+libperl='libperl.so'
+libpth='/usr/local/lib /usr/shlib /usr/ccs/lib /usr/lib/cmplrs/cc /usr/lib /var/shlib'
+libs='-ldbm -ldb -lm -lutil'
+libsdirs=' /usr/ccs/lib /usr/local/lib /usr/shlib'
+libsfiles=' libdbm.a libdb.so libm.so libutil.a'
+libsfound=' /usr/ccs/lib/libdbm.a /usr/local/lib/libdb.so /usr/shlib/libm.so /usr/ccs/lib/libutil.a'
+libspath=' /usr/local/lib /usr/shlib /usr/ccs/lib /usr/lib/cmplrs/cc /usr/lib /var/shlib'
+libswanted='sfio socket bind inet nsl nm gdbm dbm db malloc dld ld sun m crypt sec util cposix posix ucb BSD'
 libswanted_uselargefiles=''
 line=''
 lint=''
 lkflags=''
 ln='ln'
-lns='/bin/ln -s'
+lns='/usr/bin/ln -s'
 localtime_r_proto='0'
 locincpth='/usr/local/include /opt/local/include /usr/gnu/include /opt/gnu/include /usr/GNU/include /opt/GNU/include'
 loclibpth='/usr/local/lib /opt/local/lib /usr/gnu/lib /opt/gnu/lib /usr/GNU/lib /opt/GNU/lib'
-longdblsize='8'
+longdblsize='16'
 longlongsize='8'
-longsize='4'
+longsize='8'
 lp=''
 lpr=''
 ls='ls'
@@ -757,25 +757,25 @@ modetype='mode_t'
 more='more'
 multiarch='undef'
 mv=''
-myarchname='armv4l-linux'
+myarchname='alpha-dec_osf'
 mydomain='.yourplace.com'
 myhostname='yourhost'
-myuname='linux bagpuss.unfortu.net 2.4.19-rmk4 #3 fri oct 25 21:57:55 bst 2002 armv4l unknown '
-n='-n'
+myuname='osf1 kosh.hut.fi v5.1 2650 alpha '
+n=''
 need_va_copy='undef'
-netdb_hlen_type='size_t'
-netdb_host_type='const void *'
+netdb_hlen_type='int'
+netdb_host_type='const char *'
 netdb_name_type='const char *'
-netdb_net_type='in_addr_t'
+netdb_net_type='int'
 nm='nm'
-nm_opt=''
-nm_so_opt='--dynamic'
+nm_opt='-p'
+nm_so_opt=''
 nonxs_ext='Errno'
 nroff='nroff'
 nvEUformat='"E"'
 nvFUformat='"F"'
 nvGUformat='"G"'
-nv_preserves_uv_bits='32'
+nv_preserves_uv_bits='53'
 nveformat='"e"'
 nvfformat='"f"'
 nvgformat='"g"'
@@ -784,37 +784,38 @@ nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 old_pthread_create_joinable=''
-optimize='-O2'
+optimize='-O4'
 orderlib='false'
-osname='linux'
-osvers='2.4.19-rmk4'
+osname='dec_osf'
+osvers='5.1b'
 otherlibdirs=' '
 package='perl5'
-pager='/usr/bin/less'
+pager='/usr/local/bin/less'
 passcat='cat /etc/passwd'
-patchlevel='8'
+patchlevel='9'
 path_sep=':'
-perl5='/usr/local/bin/perl'
+perl5='perl'
 perl=''
-perl_patchlevel=''
+perl_patchlevel='20173'
 perladmin='yourname@yourhost.yourplace.com'
-perllibs='-lnsl -ldl -lm -lcrypt -lutil -lc'
-perlpath='/opt/perl/bin/perl'
+perllibs='-lm -lutil'
+perlpath='/opt/perl/bin/perl5.9.0'
 pg='pg'
 phostname=''
 pidtype='pid_t'
 plibpth=''
+pm_apiversion='5.005'
 pmake=''
 pr=''
 prefix='/opt/perl'
 prefixexp='/opt/perl'
-privlib='/opt/perl/lib/5.8.4'
-privlibexp='/opt/perl/lib/5.8.4'
-procselfexe='"/proc/self/exe"'
+privlib='/opt/perl/lib/5.9.0'
+privlibexp='/opt/perl/lib/5.9.0'
+procselfexe=''
 prototype='define'
-ptrsize='4'
-quadkind='3'
-quadtype='long long'
+ptrsize='8'
+quadkind='2'
+quadtype='long'
 randbits='48'
 randfunc='drand48'
 random_r_proto='0'
@@ -827,21 +828,21 @@ revision='5'
 rm='rm'
 rmail=''
 run=''
-runnm='false'
-sPRIEUldbl='"E"'
-sPRIFUldbl='"F"'
-sPRIGUldbl='"G"'
-sPRIXU64='"LX"'
-sPRId64='"Ld"'
-sPRIeldbl='"e"'
-sPRIfldbl='"f"'
-sPRIgldbl='"g"'
-sPRIi64='"Li"'
-sPRIo64='"Lo"'
-sPRIu64='"Lu"'
-sPRIx64='"Lx"'
-sSCNfldbl='"f"'
-sched_yield='sched_yield()'
+runnm='true'
+sPRIEUldbl='"LE"'
+sPRIFUldbl='"LF"'
+sPRIGUldbl='"LG"'
+sPRIXU64='"lX"'
+sPRId64='"ld"'
+sPRIeldbl='"Le"'
+sPRIfldbl='"Lf"'
+sPRIgldbl='"Lg"'
+sPRIi64='"li"'
+sPRIo64='"lo"'
+sPRIu64='"lu"'
+sPRIx64='"lx"'
+sSCNfldbl='"Lf"'
+sched_yield='undef'
 scriptdir='/opt/perl/bin'
 scriptdirexp='/opt/perl/bin'
 sed='sed'
@@ -863,24 +864,24 @@ shmattype='void *'
 shortsize='2'
 shrpenv=''
 shsharp='true'
-sig_count='64'
-sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR SYS RTMIN NUM33 NUM34 NUM35 NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 NUM48 NUM49 NUM50 NUM51 NUM52 NUM53 NUM54 NUM55 NUM56 NUM57 NUM58 NUM59 NUM60 NUM61 NUM62 RTMAX IOT CLD POLL UNUSED '
-sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "SYS", "RTMIN", "NUM33", "NUM34", "NUM35", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "NUM48", "NUM49", "NUM50", "NUM51", "NUM52", "NUM53", "NUM54", "NUM55", "NUM56", "NUM57", "NUM58", "NUM59", "NUM60", "NUM61", "NUM62", "RTMAX", "IOT", "CLD", "POLL", "UNUSED", 0'
-sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 6 17 29 31 '
-sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 6, 17, 29, 31, 0'
-sig_size='68'
+sig_count='49'
+sig_name='ZERO HUP INT QUIT ILL TRAP ABRT EMT FPE KILL BUS SEGV SYS PIPE ALRM TERM IOINT STOP TSTP CONT CHLD TTIN TTOU AIO XCPU XFSZ VTALRM PROF WINCH INFO USR1 USR2 RESV RTMIN NUM34 NUM35 NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 MAX IOT LOST URG CLD IO POLL PTY PWR RTMAX '
+sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "EMT", "FPE", "KILL", "BUS", "SEGV", "SYS", "PIPE", "ALRM", "TERM", "IOINT", "STOP", "TSTP", "CONT", "CHLD", "TTIN", "TTOU", "AIO", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "INFO", "USR1", "USR2", "RESV", "RTMIN", "NUM34", "NUM35", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "MAX", "IOT", "LOST", "URG", "CLD", "IO", "POLL", "PTY", "PWR", "RTMAX", 0'
+sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 6 6 16 20 23 23 23 29 48 '
+sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 6, 6, 16, 20, 23, 23, 23, 29, 48, 0'
+sig_size='58'
 signal_t='void'
-sitearch='/opt/perl/lib/site_perl/5.8.4/armv4l-linux'
-sitearchexp='/opt/perl/lib/site_perl/5.8.4/armv4l-linux'
+sitearch='/opt/perl/lib/site_perl/5.9.0/alpha-dec_osf'
+sitearchexp='/opt/perl/lib/site_perl/5.9.0/alpha-dec_osf'
 sitebin='/opt/perl/bin'
 sitebinexp='/opt/perl/bin'
 sitehtml1dir=''
 sitehtml1direxp=''
 sitehtml3dir=''
 sitehtml3direxp=''
-sitelib='/opt/perl/lib/site_perl/5.8.4'
+sitelib='/opt/perl/lib/site_perl/5.9.0'
 sitelib_stem='/opt/perl/lib/site_perl'
-sitelibexp='/opt/perl/lib/site_perl/5.8.4'
+sitelibexp='/opt/perl/lib/site_perl/5.9.0'
 siteman1dir='/opt/perl/man/man1'
 siteman1direxp='/opt/perl/man/man1'
 siteman3dir='/opt/perl/man/man3'
@@ -889,14 +890,14 @@ siteprefix='/opt/perl'
 siteprefixexp='/opt/perl'
 sitescript='/opt/perl/bin'
 sitescriptexp='/opt/perl/bin'
-sizesize='4'
+sizesize='8'
 sizetype='size_t'
 sleep=''
 smail=''
 so='so'
 sockethdr=''
 socketlib=''
-socksizetype='socklen_t'
+socksizetype='int'
 sort='sort'
 spackage='Perl5'
 spitshell='cat'
@@ -904,20 +905,20 @@ srand48_r_proto='0'
 srandom_r_proto='0'
 src='.'
 ssizetype='ssize_t'
-startperl='#!/opt/perl/bin/perl'
+startperl='#!/opt/perl/bin/perl5.9.0'
 startsh='#!/bin/sh'
 static_ext=' '
 stdchar='char'
-stdio_base='((fp)->_IO_read_base)'
-stdio_bufsiz='((fp)->_IO_read_end - (fp)->_IO_read_base)'
-stdio_cnt='((fp)->_IO_read_end - (fp)->_IO_read_ptr)'
+stdio_base='((fp)->_base)'
+stdio_bufsiz='((fp)->_cnt + (fp)->_ptr - (fp)->_base)'
+stdio_cnt='((fp)->_cnt)'
 stdio_filbuf=''
-stdio_ptr='((fp)->_IO_read_ptr)'
-stdio_stream_array=''
+stdio_ptr='((fp)->_ptr)'
+stdio_stream_array='_iob'
 strerror_r_proto='0'
 strings='/usr/include/string.h'
 submit=''
-subversion='4'
+subversion='0'
 sysman='/usr/share/man/man1'
 tail=''
 tar=''
@@ -925,7 +926,7 @@ targetarch=''
 tbl=''
 tee=''
 test='test'
-timeincl='/usr/include/sys/time.h /usr/include/time.h '
+timeincl='/usr/include/sys/time.h '
 timetype='time_t'
 tmpnam_r_proto='0'
 to=':'
@@ -937,38 +938,37 @@ ttyname_r_proto='0'
 u16size='2'
 u16type='unsigned short'
 u32size='4'
-u32type='unsigned long'
+u32type='unsigned int'
 u64size='8'
-u64type='unsigned long long'
+u64type='unsigned long'
 u8size='1'
 u8type='unsigned char'
-uidformat='"lu"'
+uidformat='"u"'
 uidsign='1'
 uidsize='4'
 uidtype='uid_t'
 uname='uname'
 uniq='uniq'
-uquadtype='unsigned long long'
+uquadtype='unsigned long'
 use5005threads='undef'
-use64bitall='undef'
-use64bitint='undef'
+use64bitall='define'
+use64bitint='define'
 usecrosscompile='undef'
 usedl='define'
-usefaststdio='define'
+usefaststdio='undef'
 useithreads='undef'
 uselargefiles='define'
 uselongdouble='undef'
-usemallocwrap='define'
 usemorebits='undef'
 usemultiplicity='undef'
 usemymalloc='n'
-usenm='false'
+usenm='true'
 useopcode='true'
 useperlio='define'
 useposix='true'
 usereentrant='undef'
 usesfio='false'
-useshrplib='false'
+useshrplib='true'
 usesocks='undef'
 usethreads='undef'
 usevendorprefix='undef'
@@ -977,7 +977,7 @@ usrinc='/usr/include'
 uuname=''
 uvXUformat='"lX"'
 uvoformat='"lo"'
-uvsize='4'
+uvsize='8'
 uvtype='unsigned long'
 uvuformat='"lu"'
 uvxformat='"lx"'
@@ -1000,32 +1000,39 @@ vendorprefix=''
 vendorprefixexp=''
 vendorscript=''
 vendorscriptexp=''
-version='5.8.4'
-version_patchlevel_string='version 8 subversion 4'
-versiononly='undef'
+version='5.9.0'
+version_patchlevel_string='version 9 subversion 0 patch 20173'
+versiononly='define'
 vi=''
 voidflags='15'
 xlibpth='/usr/lib/386 /lib/386'
-yacc='yacc'
+xs_apiversion='5.9.0'
+perl5='yacc'
 yaccflags=''
 zcat=''
 zip='zip'
 # Configure command line arguments.
 config_arg0='./Configure'
-config_args='-Dprefix=/opt/perl -Dcf_by=yourname -Dcf_email=yourname@yourhost.yourplace.com -Dperladmin=yourname@yourhost.yourplace.com -Dmydomain=.yourplace.com -Dmyhostname=yourhost -dE'
-config_argc=7
+config_args='-Dprefix=/opt/perl -Duse64bitint -Duselargefiles -Dcf_by=yourname -Dcf_email=yourname@yourhost.yourplace.com -Dperladmin=yourname@yourhost.yourplace.com -Dmydomain=.yourplace.com -Dmyhostname=yourhost -dE -Dusedevel'
+config_argc=10
 config_arg1='-Dprefix=/opt/perl'
-config_arg2='-Dcf_by=yourname'
-config_arg3='-Dcf_email=yourname@yourhost.yourplace.com'
-config_arg4='-Dperladmin=yourname@yourhost.yourplace.com'
-config_arg5='-Dmydomain=.yourplace.com'
-config_arg6='-Dmyhostname=yourhost'
-config_arg7='-dE'
+config_arg2='-Duse64bitint'
+config_arg3='-Duselargefiles'
+config_arg4='-Dcf_by=yourname'
+config_arg5='-Dcf_email=yourname@yourhost.yourplace.com'
+config_arg6='-Dperladmin=yourname@yourhost.yourplace.com'
+config_arg7='-Dmydomain=.yourplace.com'
+config_arg8='-Dmyhostname=yourhost'
+config_arg9='-dE'
+config_arg10='-Dusedevel'
 PERL_REVISION=5
-PERL_VERSION=8
-PERL_SUBVERSION=4
+PERL_VERSION=9
+PERL_SUBVERSION=0
 PERL_API_REVISION=5
 PERL_API_VERSION=8
 PERL_API_SUBVERSION=0
-PERL_PATCHLEVEL=
+PERL_PATCHLEVEL=20173
 PERL_CONFIG_SH=true
+# Variables propagated from previous config.sh file.
+pp_sys_cflags=''
+toke_cflags=''
