@@ -33,8 +33,8 @@ apirevision=''
 apisubversion=''
 apiversion=''
 ar='arm-epoc-pe-ar'
-archlib='/usr/lib/perl/5.8.0/epoc'
-archlibexp='/usr/lib/perl/5.8.0/epoc'
+archlib='/usr/lib/perl/5.9.0/epoc'
+archlibexp='/usr/lib/perl/5.9.0/epoc'
 archname64=''
 archname='epoc'
 archobjs='epoc.o epocish.o epoc_stubs.o'
@@ -103,13 +103,7 @@ d_archlib='define'
 d_asctime_r='undef'
 d_atolf='undef'
 d_atoll='undef'
-d_attribute_format='undef'
-d_attribute_malloc='undef'
-d_attribute_nonnull='undef'
-d_attribute_noreturn='undef'
-d_attribute_pure='undef'
-d_attribute_unused='undef'
-d_attribute_warn_unused_result='undef'
+d_attribut='undef'
 d_bcmp='define'
 d_bcopy='define'
 d_bsd='undef'
@@ -123,24 +117,20 @@ d_chown='undef'
 d_chroot='undef'
 d_chsize='undef'
 d_class='undef'
-d_clearenv='define'
 d_closedir='undef'
 d_cmsghdr_s='undef'
 d_cmsghdr_s='undef'
 d_const='define'
 d_copysignl='undef'
-d_cplusplus='undef'
 d_crypt='undef'
 d_crypt_r='undef'
 d_csh='undef'
 d_ctermid_r='undef'
 d_ctime_r='undef'
-d_c99_variadic_macros='undef'
 d_cuserid='undef'
 d_dbl_dig='undef'
 d_dbminitproto='undef'
 d_difftime='define'
-d_dir_dd_fd='undef'
 d_dirfd='undef'
 d_dirnamlen='undef'
 d_dlerror='undef'
@@ -195,7 +185,6 @@ d_fstatvfs='undef'
 d_fsync='undef'
 d_ftello='undef'
 d_ftime='undef'
-d_futimes='undef'
 d_getespwnam='undef'
 d_getfsstat='undef'
 d_getgrent='undef'
@@ -271,7 +260,6 @@ d_ldbl_dig='undef'
 d_link='undef'
 d_llseek='undef'
 d_localtime_r='undef'
-d_localtime_r_needs_tzset='undef'
 d_locconv='undef'
 d_lockf='undef'
 d_longdbl='undef'
@@ -279,8 +267,6 @@ d_longlong='define'
 d_lseekproto='define'
 d_lstat='undef'
 d_madvise='undef'
-d_malloc_good_size='undef'
-d_malloc_size='undef'
 d_mblen='undef'
 d_mbstowcs='undef'
 d_mbtowc='undef'
@@ -294,7 +280,6 @@ d_mkfifo='undef'
 d_mktime='define'
 d_mmap='undef'
 d_modfl='undef'
-d_modflproto='undef'
 d_modfl_pow32_bug='undef'
 d_mprotect='undef'
 d_msg='undef'
@@ -409,7 +394,6 @@ d_shmget='undef'
 d_sigaction='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
-d_snprintf='undef'
 d_sockatmark='undef'
 d_sockatmarkproto='undef'
 d_socket='define'
@@ -437,8 +421,6 @@ d_strerrm='strerror(e)'
 d_strerror='define'
 d_strerror_r='undef'
 d_strftime='define'
-d_strlcat='undef'
-d_strlcpy='undef'
 d_strtod='define'
 d_strtol='define'
 d_strtoq='undef'
@@ -472,7 +454,6 @@ d_umask='undef'
 d_uname='undef'
 d_union_semun='undef'
 d_unordered='undef'
-d_unsetenv='undef'
 d_usleepproto='undef'
 d_vendorlib='undef'
 d_vfork='undef'
@@ -481,7 +462,6 @@ d_voidsig='undef'
 d_voidtty='undef'
 d_volatile='define'
 d_vprintf='define'
-d_vsnprintf='undef'
 d_wait4='undef'
 d_waitpid='undef'
 d_wcstombs='undef'
@@ -665,7 +645,6 @@ lpr=''
 ls='ls'
 lseeksize='8'
 lseektype='off_t'
-mad='undef'
 mail=''
 mailx=''
 make='make'
@@ -740,8 +719,8 @@ pmake=''
 pr=''
 prefix=''
 prefixexp=''
-privlib='/usr/lib/perl/5.8.0'
-privlibexp='/usr/lib/perl/5.8.0'
+privlib='/usr/lib/perl/5.9.0'
+privlibexp='/usr/lib/perl/5.9.0'
 procselfexe=''
 prototype='define'
 ptrsize='4'
@@ -796,11 +775,11 @@ sig_num='0'
 sig_num_init='0, 0'
 sig_size='1'
 signal_t='void'
-sitearch='/usr/lib/perl/site_perl/5.8.0/epoc'
-sitearchexp='/usr/lib/perl/site_perl/5.8.0/epoc'
-sitelib='/usr/lib/perl/site_perl/5.8.0/'
+sitearch='/usr/lib/perl/site_perl/5.9.0/epoc'
+sitearchexp='/usr/lib/perl/site_perl/5.9.0/epoc'
+sitelib='/usr/lib/perl/site_perl/5.9.0/'
 sitelib_stem='/usr/lib/perl/site_perl'
-sitelibexp='/usr/lib/perl/site_perl/5.8.0/'
+sitelibexp='/usr/lib/perl/site_perl/5.9.0/'
 siteprefix=''
 siteprefixexp=''
 sizesize='4'
@@ -854,10 +833,9 @@ use64bitall='undef'
 use64bitint='undef'
 usecrosscompile='define'
 usedl='undef'
-usefaststdio='define'
+usefaststdio='undef'
 uselargefiles='undef'
 uselongdouble='undef'
-usemallocwrap='undef'
 usemorebits='undef'
 usemultiplicity='undef'
 usemymalloc='n'
@@ -866,10 +844,8 @@ useopcode=''
 useperlio='undef'
 useposix=''
 usereentrant='undef'
-userelocatableinc='undef'
 usesfio=''
 useshrplib=''
-usesitecustomize='undef'
 usesocks='undef'
 usethreads='undef'
 usevendorprefix=''
@@ -881,7 +857,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.8.0'
+version='5.9.0'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -941,7 +917,6 @@ u64size='8'
 d_fs_data_s='undef'
 d_fseeko='undef'
 d_ldbl_dig='undef'
-d_sprintf_returns_strlen='undef'
 d_sqrtl='undef'
 d_getmnt='undef'
 d_statfs_f_flags='undef'
@@ -967,7 +942,6 @@ d_strtoll='undef'
 d_strtouq='undef'
 d_nv_preserves_uv='define'
 nv_preserves_uv_bits='32'
-use5005threads='undef'
 useithreads='undef'
 inc_version_list=' '
 inc_version_list_init='0'
@@ -1014,7 +988,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.8.0'
+version='5.9.0'
 vi=''
 voidflags='15'
 xlibpth=''
@@ -1095,7 +1069,6 @@ d_strtold='undef'
 d_strtoll='undef'
 d_strtouq='undef'
 d_nv_preserves_uv='define'
-d_nv_zero_is_allbits_zero='undef'
 use5005threads='undef'
 useithreads='undef'
 inc_version_list=' '
@@ -1121,6 +1094,7 @@ mmaptype=''
 revision='5'
 sizesize='4'
 socksizetype='int'
+xs_apiversion='5.005'
 d_getcwd='define'
 i_sysmode='undef'
 d_vendorarch='undef'
@@ -1151,24 +1125,5 @@ installsitelib='/home/of/PERL/perl/lib/site_perl/5.6.0'
 installstyle=''
 installusrbinperl='undef'
 installvendorlib=''
-nveformat='"e"'
-nvfformat='"f"'
-nvgformat='"g"'
-sSCNfldbl=''
-uquadtype='uint64_t'
-d_builtin_choose_expr='undef'
-d_builtin_expect='undef'
-d_ctermid='undef'
-d_inc_version_list='undef'
-d_libm_lib_version='0'
-d_printf_format_null='undef'
-d_pseudofork='undef'
-d_signbit='undef'
-d_sitearch='undef'
-db_version_major='0'
-db_version_minor='0'
-db_version_patch='0'
-targetarch=''
-vendorarch=''
-vendorarchexp=''
+
 
