@@ -1,4 +1,3 @@
-#./perl -w
 #
 # Create the export list for perl.
 #
@@ -9,12 +8,8 @@
 # reads global.sym, pp.sym, perlvars.h, intrpvar.h, thrdvar.h, config.h
 # On OS/2 reads miniperl.map and the previous version of perl5.def as well
 
-BEGIN { unshift @INC, "lib" }
-use strict;
-
-use vars qw($PLATFORM $CCTYPE $FILETYPE $CONFIG_ARGS $ARCHNAME $PATCHLEVEL);
-
-my (%define, %ordinal);
+my $PLATFORM;
+my $CCTYPE;
 
 while (@ARGV) {
     my $flag = shift;
@@ -41,25 +36,6 @@ my %PLATFORM;
 defined $PLATFORM || die "PLATFORM undefined, must be one of: @PLATFORM\n";
 exists $PLATFORM{$PLATFORM} || die "PLATFORM must be one of: @PLATFORM\n";
 
-if ($PLATFORM eq 'win32' or $PLATFORM eq 'wince' or $PLATFORM eq "aix") {
-	# Add the compile-time options that miniperl was built with to %define.
-	# On Win32 these are not the same options as perl itself will be built
-	# with since miniperl is built with a canned config (one of the win32/
-	# config_H.*) and none of the BUILDOPT's that are set in the makefiles,
-	# but they do include some #define's that are hard-coded in various
-	# source files and header files and don't include any BUILDOPT's that
-	# the user might have chosen to disable because the canned configs are
-	# minimal configs that don't include any of those options.
-	my $opts = ($PLATFORM eq 'wince' ? '-MCross' : ''); # for wince need Cross.pm to get Config.pm
-	my $config = `$^X $opts -Ilib -V`;
-	my($options) = $config =~ /^  Compile-time options: (.*?)\n^  \S/ms;
-	$options =~ s/\s+/ /g;
-	print STDERR "Options: ($options)\n";
-	foreach (split /\s+/, $options) {
-		$define{$_} = 1;
-	}
-}
-
 my %exportperlmalloc =
     (
        Perl_malloc		=>	"malloc",
@@ -79,7 +55,6 @@ my $global_sym  = "global.sym";
 my $pp_sym      = "pp.sym";
 my $globvar_sym = "globvar.sym";
 my $perlio_sym  = "perlio.sym";
-my $static_ext = "";
 
 if ($PLATFORM eq 'aix') {
     # Nothing for now.
@@ -113,13 +88,6 @@ unless ($PLATFORM eq 'win32' || $PLATFORM eq 'wince' || $PLATFORM eq 'MacOS' ||
     }
     close(CFG);
 }
-if ($PLATFORM eq 'win32' || $PLATFORM eq 'wince') {
-    open(CFG,"<..\\$config_sh") || die "Cannot open ..\\$config_sh: $!\n";
-    if ((join '', <CFG>) =~ /^static_ext='(.*)'$/m) {
-        $static_ext = $1;
-    }
-    close(CFG);
-}
 
 open(CFG,$config_h) || die "Cannot open $config_h: $!\n";
 while (<CFG>) {
@@ -127,7 +95,6 @@ while (<CFG>) {
     $define{$1} = 1 if /^\s*#\s*define\s+(MULTIPLICITY)\b/;
     $define{$1} = 1 if /^\s*#\s*define\s+(PERL_\w+)\b/;
     $define{$1} = 1 if /^\s*#\s*define\s+(USE_\w+)\b/;
-    $define{$1} = 1 if /^\s*#\s*define\s+(HAS_\w+)\b/;
 }
 close(CFG);
 
@@ -145,7 +112,6 @@ if ($define{USE_ITHREADS}) {
 
 $define{PERL_IMPLICIT_CONTEXT} ||=
     $define{USE_ITHREADS} ||
-    $define{USE_5005THREADS}  ||
     $define{MULTIPLICITY} ;
 
 if ($define{USE_ITHREADS} && $PLATFORM ne 'win32' && $^O ne 'darwin') {
@@ -156,16 +122,11 @@ if ($define{USE_ITHREADS} && $PLATFORM ne 'win32' && $^O ne 'darwin') {
 
 my $sym_ord = 0;
 
-print STDERR "Defines: (" . join(' ', sort keys %define) . ")\n";
-
 if ($PLATFORM =~ /^win(?:32|ce)$/) {
-    (my $dll = ($define{PERL_DLL} || "perl58")) =~ s/\.dll$//i;
+    warn join(' ',keys %define)."\n";
+    ($dll = ($define{PERL_DLL} || "perl59")) =~ s/\.dll$//i;
     print "LIBRARY $dll\n";
-    # The DESCRIPTION module definition file statement is not supported
-    # by VC7 onwards.
-    if ($CCTYPE !~ /^MSVC7/ && $CCTYPE !~ /^MSVC8/ && $CCTYPE !~ /^MSVC9/) {
-	print "DESCRIPTION 'Perl interpreter'\n";
-    }
+    print "DESCRIPTION 'Perl interpreter'\n";
     print "EXPORTS\n";
     if ($define{PERL_IMPLICIT_SYS}) {
 	output_symbol("perl_get_host_info");
@@ -187,11 +148,11 @@ elsif ($PLATFORM eq 'os2') {
       }
       $sym_ord < $_ and $sym_ord = $_ for values %ordinal; # Take the max
     }
-    (my $v = $]) =~ s/(\d\.\d\d\d)(\d\d)$/$1_$2/;
+    ($v = $]) =~ s/(\d\.\d\d\d)(\d\d)$/$1_$2/;
     $v .= '-thread' if $ARCHNAME =~ /-thread/;
-    (my $dll = $define{PERL_DLL}) =~ s/\.dll$//i;
+    ($dll = $define{PERL_DLL}) =~ s/\.dll$//i;
     $v .= "\@$PATCHLEVEL" if $PATCHLEVEL;
-    my $d = "DESCRIPTION '\@#perl5-porters\@perl.org:$v#\@ Perl interpreter, configured as $CONFIG_ARGS'";
+    $d = "DESCRIPTION '\@#perl5-porters\@perl.org:$v#\@ Perl interpreter, configured as $CONFIG_ARGS'";
     $d = substr($d, 0, 249) . "...'" if length $d > 253;
     print <<"---EOP---";
 LIBRARY '$dll' INITINSTANCE TERMINSTANCE
@@ -203,9 +164,9 @@ EXPORTS
 ---EOP---
 }
 elsif ($PLATFORM eq 'aix') {
-    my $OSVER = `uname -v`;
+    $OSVER = `uname -v`;
     chop $OSVER;
-    my $OSREL = `uname -r`;
+    $OSREL = `uname -r`;
     chop $OSREL;
     if ($OSVER > 4 || ($OSVER == 4 && $OSREL >= 3)) {
 	print "#! ..\n";
@@ -215,7 +176,7 @@ elsif ($PLATFORM eq 'aix') {
 }
 elsif ($PLATFORM eq 'netware') {
 	if ($FILETYPE eq 'def') {
-	print "LIBRARY perl58\n";
+	print "LIBRARY perl59\n";
 	print "DESCRIPTION 'Perl interpreter for NetWare'\n";
 	print "EXPORTS\n";
 	}
@@ -259,6 +220,7 @@ if ($PLATFORM eq 'win32') {
 		     PL_linestart
 		     PL_modcount
 		     PL_pending_ident
+		     PL_sortcxix
 		     PL_sublex_info
 		     PL_timesbuf
 		     main
@@ -296,7 +258,6 @@ if ($PLATFORM eq 'win32') {
 		     Perl_getenv_len
 		     Perl_my_pclose
 		     Perl_my_popen
-		     Perl_my_sprintf
 		     )];
 }
 else {
@@ -317,6 +278,7 @@ if ($PLATFORM eq 'wince') {
 		     PL_linestart
 		     PL_modcount
 		     PL_pending_ident
+		     PL_sortcxix
 		     PL_sublex_info
 		     PL_timesbuf
 		     PL_collation_ix
@@ -373,7 +335,6 @@ if ($PLATFORM eq 'wince') {
 		     Perl_getenv_len
 		     Perl_my_pclose
 		     Perl_my_popen
-		     Perl_my_sprintf
 		     )];
 }
 elsif ($PLATFORM eq 'aix') {
@@ -398,19 +359,11 @@ elsif ($PLATFORM eq 'aix') {
 		     Perl_sys_intern_clear
 		     Perl_sys_intern_dup
 		     Perl_sys_intern_init
-		     Perl_my_sprintf
 		     PL_cryptseen
 		     PL_opsave
 		     PL_statusvalue_vms
 		     PL_sys_intern
 		     )]);
-    skip_symbols([qw(
-		     Perl_signbit
-		     )])
-	if $define{'HAS_SIGNBIT'};
-    emit_symbols([qw(
-		     boot_DynaLoader
-		     )]);
 }
 elsif ($PLATFORM eq 'os2') {
     emit_symbols([qw(
@@ -424,8 +377,6 @@ elsif ($PLATFORM eq 'os2') {
 		    dlsym
 		    dlerror
 		    dlclose
-		    dup2
-		    dup
 		    my_tmpfile
 		    my_tmpnam
 		    my_flock
@@ -447,10 +398,6 @@ elsif ($PLATFORM eq 'os2') {
 		    nthreads_cond
 		    os2_cond_wait
 		    os2_stat
-		    os2_execname
-		    async_mssleep
-		    msCounter
-		    InfoTable
 		    pthread_join
 		    pthread_create
 		    pthread_detach
@@ -526,6 +473,7 @@ elsif ($PLATFORM eq 'netware') {
 			PL_linestart
 			PL_modcount
 			PL_pending_ident
+			PL_sortcxix
 			PL_sublex_info
 			PL_timesbuf
 			main
@@ -599,19 +547,13 @@ unless ($define{'DEBUGGING'}) {
 		    Perl_debprofdump
 		    Perl_debstack
 		    Perl_debstackptrs
-		    Perl_hv_assert
+		    Perl_sv_peek
 		    PL_block_type
 		    PL_watchaddr
 		    PL_watchok
 		    )];
 }
 
-if ($define{'PERL_IMPLICIT_CONTEXT'}) {
-    skip_symbols [qw(
-		    PL_sig_sv
-		    )];
-}
-
 if ($define{'PERL_IMPLICIT_SYS'}) {
     skip_symbols [qw(
 		    Perl_getenv_len
@@ -633,6 +575,13 @@ else {
 		    )];
 }
 
+unless ($define{'PERL_COPY_ON_WRITE'}) {
+    skip_symbols [qw(
+		    Perl_sv_setsv_cow
+		    Perl_sv_release_IVX
+		  )];
+}
+
 unless ($define{'PERL_FLEXIBLE_EXCEPTIONS'}) {
     skip_symbols [qw(
 		    PL_protect
@@ -656,7 +605,7 @@ if ($define{'MYMALLOC'}) {
 		    MallocCfg_ptr
 		    MallocCfgP_ptr
 		    )];
-    if ($define{'USE_5005THREADS'} || $define{'USE_ITHREADS'}) {
+    if ($define{'USE_ITHREADS'}) {
 	emit_symbols [qw(
 			PL_malloc_mutex
 			)];
@@ -678,19 +627,13 @@ else {
 		    )];
 }
 
-if ($define{'PERL_USE_SAFE_PUTENV'}) {
-    skip_symbols [qw(
-                   PL_use_safe_putenv
-                  )];
-}
-
-unless ($define{'USE_5005THREADS'} || $define{'USE_ITHREADS'}) {
+unless ($define{'USE_ITHREADS'}) {
     skip_symbols [qw(
 		    PL_thr_key
 		    )];
 }
 
-unless ($define{'USE_5005THREADS'}) {
+# USE_5005THREADS symbols. Kept as reference for easier removal
     skip_symbols [qw(
 		    PL_sv_mutex
 		    PL_strtab_mutex
@@ -717,20 +660,16 @@ unless ($define{'USE_5005THREADS'}) {
 		    Perl_magic_mutexfree
 		    Perl_sv_lock
 		    )];
-}
 
 unless ($define{'USE_ITHREADS'}) {
     skip_symbols [qw(
-		    PL_pte_root
-		    PL_pte_arenaroot
+		    PL_ptr_table
 		    PL_op_mutex
 		    PL_regex_pad
 		    PL_regex_padav
 		    PL_sharedsv_space
 		    PL_sharedsv_space_mutex
 		    PL_dollarzero_mutex
-		    PL_perlio_mutex
-		    PL_regdupe
 		    Perl_dirp_dup
 		    Perl_cx_dup
 		    Perl_si_dup
@@ -742,8 +681,15 @@ unless ($define{'USE_ITHREADS'}) {
 		    Perl_mg_dup
 		    Perl_re_dup
 		    Perl_sv_dup
-		    Perl_rvpv_dup
 		    Perl_sys_intern_dup
+		    Perl_ptr_table_clear
+		    Perl_ptr_table_fetch
+		    Perl_ptr_table_free
+		    Perl_ptr_table_new
+		    Perl_ptr_table_clear
+		    Perl_ptr_table_free
+		    Perl_ptr_table_split
+		    Perl_ptr_table_store
 		    perl_clone
 		    perl_clone_using
 		    Perl_sharedsv_find
@@ -753,8 +699,6 @@ unless ($define{'USE_ITHREADS'}) {
 		    Perl_sharedsv_thrcnt_dec
 		    Perl_sharedsv_thrcnt_inc
 		    Perl_sharedsv_unlock
-		    Perl_stashpv_hvname_match
-		    Perl_regdupe
 		    )];
 }
 
@@ -801,45 +745,6 @@ unless ($define{'THREADS_HAVE_PIDS'}) {
     skip_symbols [qw(PL_ppid)];
 }
 
-unless ($define{'DEBUG_LEAKING_SCALARS_FORK_DUMP'}) {
-    skip_symbols [qw(
-		    PL_dumper_fd
-		    )];
-}
-unless ($define{'PERL_DONT_CREATE_GVSV'}) {
-    skip_symbols [qw(
-		     Perl_gv_SVadd
-		    )];
-}
-if ($define{'SPRINTF_RETURNS_STRLEN'}) {
-    skip_symbols [qw(
-		     Perl_my_sprintf
-		    )];
-}
-
-unless ($define{'PERL_TRACK_MEMPOOL'}) {
-    skip_symbols [qw(
-                     PL_memory_debug_header
-                    )];
-}
-
-# Ideally this would also check SA_SIGINFO, but there doesn't seem to be an
-# easy way to find that out from here. Fix it if it breaks because there is
-# a platform where the logic here doesn't work, *and* the export lists have to
-# be accurate there.
-unless ($define{'d_sigaction'}) {
-    skip_symbols [qw(
-		    Perl_csighandler_va
-		    )];
-}
-
-unless ($define{'MULTIPLICITY'}) {
-    skip_symbols [qw(
-		    PL_interp_size
-		    PL_interp_size_5_8_9
-		    )];
-}
-
 sub readvar {
     my $file = shift;
     my $proc = shift || sub { "PL_$_[2]" };
@@ -854,11 +759,6 @@ sub readvar {
     return \@syms;
 }
 
-if ($define{'USE_5005THREADS'}) {
-    my $thrd = readvar($thrdvar_h);
-    skip_symbols $thrd;
-}
-
 if ($define{'PERL_GLOBAL_STRUCT'}) {
     my $global = readvar($perlvars_h);
     skip_symbols $global;
@@ -957,7 +857,6 @@ if ($define{'USE_PERLIO'}) {
     if ($define{'USE_SFIO'}) {
 	# Old legacy non-stdio "PerlIO"
 	skip_symbols \@layer_syms;
-	skip_symbols [qw(perlsio_binmode)];
 	# SFIO defines most of the PerlIO routines as macros
 	# So undo most of what $perlio_sym has just done - d'oh !
 	# Perhaps it would be better to list the ones which do exist
@@ -1035,32 +934,13 @@ if ($define{'USE_PERLIO'}) {
     else {
 	# PerlIO with layers - export implementation
 	emit_symbols \@layer_syms;
-	emit_symbols [qw(perlsio_binmode)];
-    }
-    if ($define{'USE_ITHREADS'}) {
-	emit_symbols [qw(
-			PL_perlio_mutex
-			)];
-    }
-    else {
-	skip_symbols [qw(
-			PL_perlio_mutex
-			)];
     }
 } else {
 	# -Uuseperlio
 	# Skip the PerlIO layer symbols - although
 	# nothing should have exported them any way
 	skip_symbols \@layer_syms;
-	skip_symbols [qw(
-			perlsio_binmode
-			PL_def_layerlist
-			PL_known_layers
-			PL_perlio
-			PL_perlio_debug_fd
-			PL_perlio_fd_refcnt
-			PL_perlio_fd_refcnt_size
-			)];
+        skip_symbols [qw(PL_def_layerlist PL_known_layers PL_perlio)];
 
 	# Also do NOT add abstraction symbols from $perlio_sym
 	# abstraction is done as #define to stdio
@@ -1104,7 +984,7 @@ else {
 	my $glob = readvar($intrpvar_h);
 	emit_symbols $glob;
     }
-    unless ($define{'MULTIPLICITY'} || $define{'USE_5005THREADS'}) {
+    unless ($define{'MULTIPLICITY'}) {
 	my $glob = readvar($thrdvar_h);
 	emit_symbols $glob;
     }
@@ -1146,7 +1026,6 @@ if ($PLATFORM =~ /^win(?:32|ce)$/) {
 			    win32_pclose
 			    win32_rename
 			    win32_setmode
-			    win32_chsize
 			    win32_lseek
 			    win32_tell
 			    win32_dup
@@ -1237,7 +1116,6 @@ if ($PLATFORM =~ /^win(?:32|ce)$/) {
 			    win32_rewinddir
 			    win32_closedir
 			    win32_longpath
-			    win32_ansipath
 			    win32_os_id
 			    win32_getpid
 			    win32_crypt
@@ -1291,12 +1169,8 @@ if ($PLATFORM =~ /^win(?:32|ce)$/) {
     {
 	try_symbol($symbol);
     }
-    if ($CCTYPE eq "BORLAND") {
-	try_symbol('_matherr');
-    }
 }
 elsif ($PLATFORM eq 'os2') {
-    my (%mapped, @missing);
     open MAP, 'miniperl.map' or die 'Cannot read miniperl.map';
     /^\s*[\da-f:]+\s+(\w+)/i and $mapped{$1}++ foreach <MAP>;
     close MAP or die 'Cannot close miniperl.map';
@@ -1458,17 +1332,6 @@ foreach my $symbol (qw(
     }
 }
 
-# records of type boot_module for statically linked modules (except Dynaloader)
-$static_ext =~ s/\//__/g;
-$static_ext =~ s/\bDynaLoader\b//;
-my @stat_mods = map {"boot_$_"} grep {/\S/} split /\s+/, $static_ext;
-foreach my $symbol (@stat_mods)
-    {
-	try_symbol($symbol);
-    }
-
-try_symbol("init_Win32CORE") if $static_ext =~ /\bWin32CORE\b/;
-
 # Now all symbols should be defined because
 # next we are going to output them.
 
@@ -1477,14 +1340,7 @@ foreach my $symbol (sort keys %export) {
 }
 
 if ($PLATFORM eq 'os2') {
-	print <<EOP;
-    dll_perlmain=main
-    fill_extLibpath
-    dir_subst
-    Perl_OS2_handler_install
-
-; LAST_ORDINAL=$sym_ord
-EOP
+	print "; LAST_ORDINAL=$sym_ord\n";
 }
 
 sub emit_symbol {
@@ -1538,6 +1394,17 @@ sub output_symbol {
 
 1;
 __DATA__
+# extra globals not included above.
+Perl_cxinc
+perl_alloc
+perl_alloc_using
+perl_clone
+perl_clone_using
+perl_construct
+perl_destruct
+perl_free
+perl_parse
+perl_run
 # Oddities from PerlIO
 PerlIO_binmode
 PerlIO_getpos
@@ -1547,3 +1414,4 @@ PerlIO_sprintf
 PerlIO_sv_dup
 PerlIO_tmpfile
 PerlIO_vsprintf
+perlsio_binmode
