@@ -43,23 +43,25 @@
 #define COLONATTR 298
 #define PREC_LOW 299
 #define OROP 300
-#define ANDOP 301
-#define NOTOP 302
-#define ASSIGNOP 303
-#define OROR 304
-#define ANDAND 305
-#define BITOROP 306
-#define BITANDOP 307
-#define SHIFTOP 308
-#define MATCHOP 309
-#define UMINUS 310
-#define REFGEN 311
-#define POWOP 312
-#define PREINC 313
-#define PREDEC 314
-#define POSTINC 315
-#define POSTDEC 316
-#define ARROW 317
+#define DOROP 301
+#define ANDOP 302
+#define NOTOP 303
+#define ASSIGNOP 304
+#define OROR 305
+#define DORDOR 306
+#define ANDAND 307
+#define BITOROP 308
+#define BITANDOP 309
+#define SHIFTOP 310
+#define MATCHOP 311
+#define UMINUS 312
+#define REFGEN 313
+#define POWOP 314
+#define PREINC 315
+#define PREDEC 316
+#define POSTINC 317
+#define POSTDEC 318
+#define ARROW 319
 #endif /* PERL_CORE */
 
 typedef union {
