@@ -1,7 +1,7 @@
 /*    pp_sort.c
  *
  *    Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
- *    2000, 2001, 2002, 2003, 2004, 2005, by Larry Wall and others
+ *    2000, 2001, 2002, 2003, by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
  *    License or the Artistic License, as specified in the README file.
@@ -13,17 +13,6 @@
  *   rear!'  the slave-driver shouted. 'Three files up. And stay there...
  */
 
-/* This file contains pp ("push/pop") functions that
- * execute the opcodes that make up a perl program. A typical pp function
- * expects to find its arguments on the stack, and usually pushes its
- * results onto the stack, hence the 'pp' terminology. Each OP structure
- * contains a pointer to the relevant pp_foo() function.
- *
- * This particular file just contains pp_sort(), which is complex
- * enough to merit its own file! See the other pp*.c files for the rest of
- * the pp_ functions.
- */
-
 #include "EXTERN.h"
 #define PERL_IN_PP_SORT_C
 #include "perl.h"
@@ -346,15 +335,8 @@ typedef struct {
     IV	runs;		/* how many runs must be combined into 1 */
 } off_runs;		/* pseudo-stack element */
 
-
-static I32
-cmp_desc(pTHX_ gptr a, gptr b)
-{
-    return -PL_sort_RealCmp(aTHX_ a, b);
-}
-
 STATIC void
-S_mergesortsv(pTHX_ gptr *base, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
+S_mergesortsv(pTHX_ gptr *base, size_t nmemb, SVCOMPARE_t cmp)
 {
     IV i, run, runs, offset;
     I32 sense, level;
@@ -365,16 +347,8 @@ S_mergesortsv(pTHX_ gptr *base, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
     gptr small[SMALLSORT];
     gptr *which[3];
     off_runs stack[60], *stackp;
-    SVCOMPARE_t savecmp = 0;
 
     if (nmemb <= 1) return;			/* sorted trivially */
-
-    if (flags) {
-	savecmp = PL_sort_RealCmp;	/* Save current comparison routine, if any */
-	PL_sort_RealCmp = cmp;	/* Put comparison routine where cmp_desc can find it */
-	cmp = cmp_desc;
-    }
-
     if (nmemb <= SMALLSORT) aux = small;	/* use stack for aux array */
     else { New(799,aux,nmemb,gptr); }		/* allocate auxilliary array */
     level = 0;
@@ -557,9 +531,6 @@ S_mergesortsv(pTHX_ gptr *base, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
     }
 done:
     if (aux != small) Safefree(aux);	/* free iff allocated */
-    if (flags) {
-	 PL_sort_RealCmp = savecmp;	/* Restore current comparison routine, if any */
-    }
     return;
 }
 
@@ -1329,23 +1300,8 @@ cmpindir(pTHX_ gptr a, gptr b)
     return sense;
 }
 
-static I32
-cmpindir_desc(pTHX_ gptr a, gptr b)
-{
-    I32 sense;
-    gptr *ap = (gptr *)a;
-    gptr *bp = (gptr *)b;
-
-    /* Reverse the default */
-    if ((sense = PL_sort_RealCmp(aTHX_ *ap, *bp)))
-	return -sense;
-    /* But don't reverse the stability test.  */
-    return (ap > bp) ? 1 : ((ap < bp) ? -1 : 0);
-
-}
-
 STATIC void
-S_qsortsv(pTHX_ gptr *list1, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
+S_qsortsv(pTHX_ gptr *list1, size_t nmemb, SVCOMPARE_t cmp)
 {
     SV *hintsv;
 
@@ -1367,8 +1323,7 @@ S_qsortsv(pTHX_ gptr *list1, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
 	 PL_sort_RealCmp = cmp;	/* Put comparison routine where cmpindir can find it */
 
 	 /* sort, with indirection */
-	 S_qsortsvu(aTHX_ (gptr *)indir, nmemb,
-		    flags ? cmpindir_desc : cmpindir);
+	 S_qsortsvu(aTHX_ (gptr *)indir, nmemb, cmpindir);
 
 	 pp = indir;
 	 q = list1;
@@ -1411,13 +1366,6 @@ S_qsortsv(pTHX_ gptr *list1, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
 	 if (indir != small) { Safefree(indir); }
 	 /* restore prevailing comparison routine */
 	 PL_sort_RealCmp = savecmp;
-    } else if (flags) {
-	 SVCOMPARE_t savecmp = PL_sort_RealCmp;	/* Save current comparison routine, if any */
-	 PL_sort_RealCmp = cmp;	/* Put comparison routine where cmp_desc can find it */
-	 cmp = cmp_desc;
-	 S_qsortsvu(aTHX_ list1, nmemb, cmp);
-	 /* restore prevailing comparison routine */
-	 PL_sort_RealCmp = savecmp;
     } else {
 	 S_qsortsvu(aTHX_ list1, nmemb, cmp);
     }
@@ -1440,8 +1388,8 @@ See lib/sort.pm for details about controlling the sorting algorithm.
 void
 Perl_sortsv(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp)
 {
-    void (*sortsvp)(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
-      = S_mergesortsv;
+    void (*sortsvp)(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp) =
+        S_mergesortsv;
     SV *hintsv;
     I32 hints;
 
@@ -1459,41 +1407,15 @@ Perl_sortsv(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp)
 	sortsvp = S_mergesortsv;
     }
 
-    sortsvp(aTHX_ array, nmemb, cmp, 0);
-}
-
-
-void
-S_sortsv_desc(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp)
-{
-    void (*sortsvp)(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp, U32 flags)
-      = S_mergesortsv;
-    SV *hintsv;
-    I32 hints;
-
-    /*  Sun's Compiler (cc: WorkShop Compilers 4.2 30 Oct 1996 C 4.2) used 
-	to miscompile this function under optimization -O.  If you get test 
-	errors related to picking the correct sort() function, try recompiling 
-	this file without optimiziation.  -- A.D.  4/2002.
-    */
-    hints = SORTHINTS(hintsv);
-    if (hints & HINT_SORT_QUICKSORT) {
-	sortsvp = S_qsortsv;
-    }
-    else {
-	/* The default as of 5.8.0 is mergesort */
-	sortsvp = S_mergesortsv;
-    }
-
-    sortsvp(aTHX_ array, nmemb, cmp, 1);
+    sortsvp(aTHX_ array, nmemb, cmp);
 }
 
 PP(pp_sort)
 {
     dSP; dMARK; dORIGMARK;
-    register SV **p1 = ORIGMARK+1, **p2;
-    register I32 max, i;
-    AV* av = Nullav;
+    register SV **up;
+    SV **myorigmark = ORIGMARK;
+    register I32 max;
     HV *stash;
     GV *gv;
     CV *cv = 0;
@@ -1502,11 +1424,6 @@ PP(pp_sort)
     I32 overloading = 0;
     bool hasargs = FALSE;
     I32 is_xsub = 0;
-    I32 sorting_av = 0;
-    U8 priv = PL_op->op_private;
-    U8 flags = PL_op->op_flags;
-    void (*sortsvp)(pTHX_ SV **array, size_t nmemb, SVCOMPARE_t cmp)
-      = Perl_sortsv;
 
     if (gimme != G_ARRAY) {
 	SP = MARK;
@@ -1515,8 +1432,8 @@ PP(pp_sort)
 
     ENTER;
     SAVEVPTR(PL_sortcop);
-    if (flags & OPf_STACKED) {
-	if (flags & OPf_SPECIAL) {
+    if (PL_op->op_flags & OPf_STACKED) {
+	if (PL_op->op_flags & OPf_SPECIAL) {
 	    OP *kid = cLISTOP->op_first->op_sibling;	/* pass pushmark */
 	    kid = kUNOP->op_first;			/* pass rv2gv */
 	    kid = kUNOP->op_first;			/* pass leave */
@@ -1563,59 +1480,24 @@ PP(pp_sort)
 	stash = CopSTASH(PL_curcop);
     }
 
-    /* optimiser converts "@a = sort @a" to "sort \@a";
-     * in case of tied @a, pessimise: push (@a) onto stack, then assign
-     * result back to @a at the end of this function */
-    if (priv & OPpSORT_INPLACE) {
-	assert( MARK+1 == SP && *SP && SvTYPE(*SP) == SVt_PVAV);
-	(void)POPMARK; /* remove mark associated with ex-OP_AASSIGN */
-	av = (AV*)(*SP);
-	max = AvFILL(av) + 1;
-	if (SvMAGICAL(av)) {
-	    MEXTEND(SP, max);
-	    p2 = SP;
-	    for (i=0; i < max; i++) {
-		SV **svp = av_fetch(av, i, FALSE);
-		*SP++ = (svp) ? *svp : Nullsv;
-	    }
-	}
-	else {
-	    p1 = p2 = AvARRAY(av);
-	    sorting_av = 1;
-	}
-    }
-    else {
-	p2 = MARK+1;
-	max = SP - MARK;
-   }
-
-    if (priv & OPpSORT_DESCEND) {
-	sortsvp = S_sortsv_desc;
-    }
-
-    /* shuffle stack down, removing optional initial cv (p1!=p2), plus any
-     * nulls; also stringify any args */
-    for (i=max; i > 0 ; i--) {
-	if ((*p1 = *p2++)) {			/* Weed out nulls. */
-	    SvTEMP_off(*p1);
-	    if (!PL_sortcop && !SvPOK(*p1)) {
+    up = myorigmark + 1;
+    while (MARK < SP) {	/* This may or may not shift down one here. */
+	/*SUPPRESS 560*/
+	if ((*up = *++MARK)) {			/* Weed out nulls. */
+	    SvTEMP_off(*up);
+	    if (!PL_sortcop && !SvPOK(*up)) {
 		STRLEN n_a;
-	        if (SvAMAGIC(*p1))
+	        if (SvAMAGIC(*up))
 	            overloading = 1;
 	        else
-		    (void)sv_2pv(*p1, &n_a);
+		    (void)sv_2pv(*up, &n_a);
 	    }
-	    p1++;
+	    up++;
 	}
-	else
-	    max--;
     }
-    if (sorting_av)
-	AvFILLp(av) = max-1;
-
-    if (max > 1) {
-	SV **start;
-	if (PL_sortcop) {
+    max = --up - myorigmark;
+    if (PL_sortcop) {
+	if (max > 1) {
 	    PERL_CONTEXT *cx;
 	    SV** newsp;
 	    bool oldcatch = CATCH_GET;
@@ -1633,19 +1515,17 @@ PP(pp_sort)
 		    PL_secondgv = gv_fetchpv("b", TRUE, SVt_PV);
 		    PL_sortstash = stash;
 		}
-#ifdef USE_5005THREADS
-		sv_lock((SV *)PL_firstgv);
-		sv_lock((SV *)PL_secondgv);
-#endif
 		SAVESPTR(GvSV(PL_firstgv));
 		SAVESPTR(GvSV(PL_secondgv));
 	    }
 
 	    PUSHBLOCK(cx, CXt_NULL, PL_stack_base);
-	    if (!(flags & OPf_SPECIAL)) {
+	    if (!(PL_op->op_flags & OPf_SPECIAL)) {
 		cx->cx_type = CXt_SUB;
 		cx->blk_gimme = G_SCALAR;
 		PUSHSUB(cx);
+		if (!CvDEPTH(cv))
+		    (void)SvREFCNT_inc(cv); /* in preparation for POPSUB */
 	    }
 	    PL_sortcxix = cxstack_ix;
 
@@ -1653,29 +1533,26 @@ PP(pp_sort)
 		/* This is mostly copied from pp_entersub */
 		AV *av = (AV*)PAD_SVl(0);
 
-#ifndef USE_5005THREADS
 		cx->blk_sub.savearray = GvAV(PL_defgv);
 		GvAV(PL_defgv) = (AV*)SvREFCNT_inc(av);
-#endif /* USE_5005THREADS */
 		CX_CURPAD_SAVE(cx->blk_sub);
 		cx->blk_sub.argarray = av;
 	    }
-	    
-	    start = p1 - max;
-	    sortsvp(aTHX_ start, max,
-		    is_xsub ? sortcv_xsub : hasargs ? sortcv_stacked : sortcv);
+           sortsv((myorigmark+1), max,
+                  is_xsub ? sortcv_xsub : hasargs ? sortcv_stacked : sortcv);
 
 	    POPBLOCK(cx,PL_curpm);
 	    PL_stack_sp = newsp;
 	    POPSTACK;
 	    CATCH_SET(oldcatch);
 	}
-	else {
+    }
+    else {
+	if (max > 1) {
 	    MEXTEND(SP, 20);	/* Can't afford stack realloc on signal. */
-	    start = sorting_av ? AvARRAY(av) : ORIGMARK+1;
-	    sortsvp(aTHX_ start, max,
-		    (priv & OPpSORT_NUMERIC)
-			? ( (priv & OPpSORT_INTEGER)
+	    sortsv(ORIGMARK+1, max,
+                  (PL_op->op_private & OPpSORT_NUMERIC)
+			? ( (PL_op->op_private & OPpSORT_INTEGER)
 			    ? ( overloading ? amagic_i_ncmp : sv_i_ncmp)
 			    : ( overloading ? amagic_ncmp : sv_ncmp))
 			: ( IN_LOCALE_RUNTIME
@@ -1683,37 +1560,19 @@ PP(pp_sort)
 				? amagic_cmp_locale
 				: sv_cmp_locale_static)
 			    : ( overloading ? amagic_cmp : sv_cmp_static)));
-	}
-	if (priv & OPpSORT_REVERSE) {
-	    SV **q = start+max-1;
-	    while (start < q) {
-		SV *tmp = *start;
-		*start++ = *q;
-		*q-- = tmp;
+	    if (PL_op->op_private & OPpSORT_REVERSE) {
+		SV **p = ORIGMARK+1;
+		SV **q = ORIGMARK+max;
+		while (p < q) {
+		    SV *tmp = *p;
+		    *p++ = *q;
+		    *q-- = tmp;
+		}
 	    }
 	}
     }
-    if (av && !sorting_av) {
-	/* simulate pp_aassign of tied AV */
-	SV *sv;
-	SV** base, **didstore;
-	for (base = ORIGMARK+1, i=0; i < max; i++) {
-	    sv = newSVsv(base[i]);
-	    base[i] = sv;
-	}
-	av_clear(av);
-	av_extend(av, max);
-	for (i=0; i < max; i++) {
-	    sv = base[i];
-	    didstore = av_store(av, i, sv);
-	    if (SvSMAGICAL(sv))
-		mg_set(sv);
-	    if (!didstore)
-		sv_2mortal(sv);
-	}
-    }
     LEAVE;
-    PL_stack_sp = ORIGMARK + (sorting_av ? 0 : max);
+    PL_stack_sp = ORIGMARK + max;
     return nextop;
 }
 
@@ -1748,11 +1607,7 @@ sortcv_stacked(pTHX_ SV *a, SV *b)
     I32 result;
     AV *av;
 
-#ifdef USE_5005THREADS
-    av = (AV*)PAD_SVl(0);
-#else
     av = GvAV(PL_defgv);
-#endif
 
     if (AvMAX(av) < 1) {
 	SV** ary = AvALLOC(av);
@@ -1927,13 +1782,3 @@ amagic_cmp_locale(pTHX_ register SV *str1, register SV *str2)
     }
     return sv_cmp_locale(str1, str2);
 }
-
-/*
- * Local variables:
- * c-indentation-style: bsd
- * c-basic-offset: 4
- * indent-tabs-mode: t
- * End:
- *
- * vim: shiftwidth=4:
-*/
