@@ -1,7 +1,7 @@
 /*    sv.h
  *
  *    Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
- *    2000, 2001, 2002, 2003, 2004, 2005, 2006 by Larry Wall and others
+ *    2000, 2001, 2002, 2003, by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
  *    License or the Artistic License, as specified in the README file.
@@ -126,63 +126,42 @@ perform the upgrade if necessary.  See C<svtype>.
 #define SvFLAGS(sv)	(sv)->sv_flags
 #define SvREFCNT(sv)	(sv)->sv_refcnt
 
-#ifdef USE_5005THREADS
-
-#  if defined(VMS)
-#    define ATOMIC_INC(count) __ATOMIC_INCREMENT_LONG(&count)
-#    define ATOMIC_DEC_AND_TEST(res,count) res=(1==__ATOMIC_DECREMENT_LONG(&count))
- #  else
-#    ifdef EMULATE_ATOMIC_REFCOUNTS
- #      define ATOMIC_INC(count) STMT_START {	\
-	  MUTEX_LOCK(&PL_svref_mutex);		\
-	  ++count;				\
-	  MUTEX_UNLOCK(&PL_svref_mutex);		\
-       } STMT_END
-#      define ATOMIC_DEC_AND_TEST(res,count) STMT_START {	\
-	  MUTEX_LOCK(&PL_svref_mutex);			\
-	  res = (--count == 0);				\
-	  MUTEX_UNLOCK(&PL_svref_mutex);			\
-       } STMT_END
-#    else
-#      define ATOMIC_INC(count) atomic_inc(&count)
-#      define ATOMIC_DEC_AND_TEST(res,count) (res = atomic_dec_and_test(&count))
-#    endif /* EMULATE_ATOMIC_REFCOUNTS */
-#  endif /* VMS */
-#else
-#  define ATOMIC_INC(count) (++count)
-#  define ATOMIC_DEC_AND_TEST(res, count) (res = (--count == 0))
-#endif /* USE_5005THREADS */
-
 #if defined(__GNUC__) && !defined(__STRICT_ANSI__) && !defined(PERL_GCC_PEDANTIC)
 #  define SvREFCNT_inc(sv)		\
     ({					\
-	SV * const _sv = (SV*)(sv);	\
-	if (_sv)			\
-	     ATOMIC_INC(SvREFCNT(_sv));	\
-	_sv;				\
+	SV *nsv = (SV*)(sv);		\
+	if (nsv)			\
+	     (SvREFCNT(nsv))++;		\
+	nsv;				\
     })
 #else
-#  ifdef USE_5005THREADS
-#    if defined(VMS) && defined(__ALPHA)
-#      define SvREFCNT_inc(sv) \
-          (PL_Sv=(SV*)(sv), (PL_Sv && __ATOMIC_INCREMENT_LONG(&(SvREFCNT(PL_Sv)))), (SV *)PL_Sv)
-#    else
-#      define SvREFCNT_inc(sv) sv_newref((SV*)sv)
-#    endif
-#  else
-#    define SvREFCNT_inc(sv)	\
-	((PL_Sv=(SV*)(sv)), (PL_Sv && ATOMIC_INC(SvREFCNT(PL_Sv))), (SV*)PL_Sv)
-#  endif
+#  define SvREFCNT_inc(sv)	\
+	((PL_Sv=(SV*)(sv)), (PL_Sv && ++(SvREFCNT(PL_Sv))), (SV*)PL_Sv)
 #endif
 
+#if defined(__GNUC__) && !defined(__STRICT_ANSI__) && !defined(PERL_GCC_PEDANTIC)
+#  define SvREFCNT_dec(sv)		\
+    ({					\
+	SV *nsv = (SV*)(sv);		\
+	if (nsv) {			\
+	    if (SvREFCNT(nsv)) {	\
+		if (--(SvREFCNT(nsv)) == 0) \
+		    Perl_sv_free2(aTHX_ nsv);	\
+	    } else {			\
+		sv_free(nsv);		\
+	    }				\
+	}				\
+    })
+#else
 #define SvREFCNT_dec(sv)	sv_free((SV*)(sv))
+#endif
 
 #define SVTYPEMASK	0xff
 #define SvTYPE(sv)	((sv)->sv_flags & SVTYPEMASK)
 
 #define SvUPGRADE(sv, mt) (SvTYPE(sv) >= mt || sv_upgrade(sv, mt))
 
-#define SVs_PADBUSY	0x00000100	/* reserved for tmp or my already */
+#define SVs_PADSTALE	0x00000100	/* lexical has gone out of scope */
 #define SVs_PADTMP	0x00000200	/* in use as tmp */
 #define SVs_PADMY	0x00000400	/* in use a "my" variable */
 #define SVs_TEMP	0x00000800	/* string is stealable? */
@@ -234,7 +213,6 @@ perform the upgrade if necessary.  See C<svtype>.
 
 #define SVrepl_EVAL	0x40000000	/* Replacement part of s///e */
 
-#define SVphv_CLONEABLE	0x08000000	/* for stashes: clone its objects */
 #define SVphv_REHASH	0x10000000	/* HV is recalculating hash values */
 #define SVphv_SHAREKEYS 0x20000000	/* keys live on shared string table */
 #define SVphv_LAZYDEL	0x40000000	/* entry in xhv_eiter must be deleted */
@@ -354,10 +332,6 @@ struct xpvfm {
     long	xcv_depth;	/* >= 2 indicates recursive call */
     AV *	xcv_padlist;
     CV *	xcv_outside;
-#ifdef USE_5005THREADS
-    perl_mutex *xcv_mutexp;	/* protects xcv_owner */
-    struct perl_thread *xcv_owner;	/* current owner thread */
-#endif /* USE_5005THREADS */
     cv_flags_t	xcv_flags;
     U32		xcv_outside_seq; /* the COP sequence (at the point of our
 				  * compilation) in the lexically enclosing
@@ -429,8 +403,7 @@ double.  Checks the B<private> setting.  Use C<SvNIOK>.
 Unsets the NV/IV status of an SV.
 
 =for apidoc Am|bool|SvOK|SV* sv
-Returns a boolean indicating whether the value is an SV. It also tells
-whether the value is defined or not.
+Returns a boolean indicating whether the value is an SV.
 
 =for apidoc Am|bool|SvIOKp|SV* sv
 Returns a boolean indicating whether the SV contains an integer.  Checks
@@ -459,13 +432,13 @@ Tells an SV that it is an integer and disables all other OK bits.
 =for apidoc Am|void|SvIOK_only_UV|SV* sv
 Tells and SV that it is an unsigned integer and disables all other OK bits.
 
-=for apidoc Am|bool|SvIOK_UV|SV* sv
+=for apidoc Am|void|SvIOK_UV|SV* sv
 Returns a boolean indicating whether the SV contains an unsigned integer.
 
 =for apidoc Am|void|SvUOK|SV* sv
 Returns a boolean indicating whether the SV contains an unsigned integer.
 
-=for apidoc Am|bool|SvIOK_notUV|SV* sv
+=for apidoc Am|void|SvIOK_notUV|SV* sv
 Returns a boolean indicating whether the SV contains a signed integer.
 
 =for apidoc Am|bool|SvNOK|SV* sv
@@ -494,6 +467,9 @@ Unsets the PV status of an SV.
 Tells an SV that it is a string and disables all other OK bits.
 Will also turn off the UTF-8 status.
 
+=for apidoc Am|bool|SvVOK|SV* sv
+Returns a boolean indicating whether the SV contains a v-string.
+
 =for apidoc Am|bool|SvOOK|SV* sv
 Returns a boolean indicating whether the SvIVX is a valid offset value for
 the SvPVX.  This hack is used internally to speed up removal of characters
@@ -542,36 +518,8 @@ See C<SvCUR>.  Access the character as *(SvEND(sv)).
 =for apidoc Am|HV*|SvSTASH|SV* sv
 Returns the stash of the SV.
 
-=for apidoc Am|void|SvIV_set|SV* sv|IV val
-Set the value of the IV pointer in sv to val.  It is possible to perform
-the same function of this macro with an lvalue assignment to C<SvIVX>.
-With future Perls, however, it will be more efficient to use 
-C<SvIV_set> instead of the lvalue assignment to C<SvIVX>.
-
-=for apidoc Am|void|SvNV_set|SV* sv|NV val
-Set the value of the NV pointer in sv to val.  See C<SvIV_set>.
-
-=for apidoc Am|void|SvPV_set|SV* sv|char* val
-Set the value of the PV pointer in sv to val.  See C<SvIV_set>.
-
-=for apidoc Am|void|SvUV_set|SV* sv|UV val
-Set the value of the UV pointer in sv to val.  See C<SvIV_set>.
-
-=for apidoc Am|void|SvRV_set|SV* sv|SV* val
-Set the value of the RV pointer in sv to val.  See C<SvIV_set>.
-
-=for apidoc Am|void|SvMAGIC_set|SV* sv|MAGIC* val
-Set the value of the MAGIC pointer in sv to val.  See C<SvIV_set>.
-
-=for apidoc Am|void|SvSTASH_set|SV* sv|STASH* val
-Set the value of the STASH pointer in sv to val.  See C<SvIV_set>.
-
 =for apidoc Am|void|SvCUR_set|SV* sv|STRLEN len
-Set the current length of the string which is in the SV.  See C<SvCUR>
-and C<SvIV_set>.
-
-=for apidoc Am|void|SvLEN_set|SV* sv|STRLEN len
-Set the actual length of the string which is in the SV.  See C<SvIV_set>.
+Set the length of the string which is in the SV.  See C<SvCUR>.
 
 =cut
 */
@@ -599,7 +547,8 @@ Set the actual length of the string which is in the SV.  See C<SvIV_set>.
 
 #define SvOKp(sv)		(SvFLAGS(sv) & (SVp_IOK|SVp_NOK|SVp_POK))
 #define SvIOKp(sv)		(SvFLAGS(sv) & SVp_IOK)
-#define SvIOKp_on(sv)		((void)SvOOK_off(sv), SvFLAGS(sv) |= SVp_IOK)
+#define SvIOKp_on(sv)		(SvRELEASE_IVX(sv), \
+				    SvFLAGS(sv) |= SVp_IOK)
 #define SvNOKp(sv)		(SvFLAGS(sv) & SVp_NOK)
 #define SvNOKp_on(sv)		(SvFLAGS(sv) |= SVp_NOK)
 #define SvPOKp(sv)		(SvFLAGS(sv) & SVp_POK)
@@ -607,12 +556,12 @@ Set the actual length of the string which is in the SV.  See C<SvIV_set>.
 				 SvFLAGS(sv) |= SVp_POK)
 
 #define SvIOK(sv)		(SvFLAGS(sv) & SVf_IOK)
-#define SvIOK_on(sv)		((void)SvOOK_off(sv), \
+#define SvIOK_on(sv)		(SvRELEASE_IVX(sv), \
 				    SvFLAGS(sv) |= (SVf_IOK|SVp_IOK))
 #define SvIOK_off(sv)		(SvFLAGS(sv) &= ~(SVf_IOK|SVp_IOK|SVf_IVisUV))
-#define SvIOK_only(sv)		(SvOK_off(sv), \
+#define SvIOK_only(sv)		((void)SvOK_off(sv), \
 				    SvFLAGS(sv) |= (SVf_IOK|SVp_IOK))
-#define SvIOK_only_UV(sv)	(SvOK_off_exc_UV(sv), \
+#define SvIOK_only_UV(sv)	((void)SvOK_off_exc_UV(sv), \
 				    SvFLAGS(sv) |= (SVf_IOK|SVp_IOK))
 
 #define SvIOK_UV(sv)		((SvFLAGS(sv) & (SVf_IOK|SVf_IVisUV))	\
@@ -621,7 +570,6 @@ Set the actual length of the string which is in the SV.  See C<SvIV_set>.
 #define SvIOK_notUV(sv)		((SvFLAGS(sv) & (SVf_IOK|SVf_IVisUV))	\
 				 == SVf_IOK)
 
-#define SvVOK(sv)		(SvMAGICAL(sv) && mg_find(sv,'V'))
 #define SvIsUV(sv)		(SvFLAGS(sv) & SVf_IVisUV)
 #define SvIsUV_on(sv)		(SvFLAGS(sv) |= SVf_IVisUV)
 #define SvIsUV_off(sv)		(SvFLAGS(sv) &= ~SVf_IVisUV)
@@ -629,11 +577,11 @@ Set the actual length of the string which is in the SV.  See C<SvIV_set>.
 #define SvNOK(sv)		(SvFLAGS(sv) & SVf_NOK)
 #define SvNOK_on(sv)		(SvFLAGS(sv) |= (SVf_NOK|SVp_NOK))
 #define SvNOK_off(sv)		(SvFLAGS(sv) &= ~(SVf_NOK|SVp_NOK))
-#define SvNOK_only(sv)		(SvOK_off(sv), \
+#define SvNOK_only(sv)		((void)SvOK_off(sv), \
 				    SvFLAGS(sv) |= (SVf_NOK|SVp_NOK))
 
 /*
-=for apidoc Am|bool|SvUTF8|SV* sv
+=for apidoc Am|void|SvUTF8|SV* sv
 Returns a boolean indicating whether the SV contains UTF-8 encoded data.
 
 =for apidoc Am|void|SvUTF8_on|SV *sv
@@ -667,9 +615,10 @@ and leaves the UTF-8 status as it was.
 						  SVf_IVisUV),		\
 				    SvFLAGS(sv) |= (SVf_POK|SVp_POK))
 
+#define SvVOK(sv)		(SvMAGICAL(sv) && mg_find(sv,'V'))
 #define SvOOK(sv)		(SvFLAGS(sv) & SVf_OOK)
 #define SvOOK_on(sv)		((void)SvIOK_off(sv), SvFLAGS(sv) |= SVf_OOK)
-#define SvOOK_off(sv)		((void)(SvOOK(sv) && sv_backoff(sv)))
+#define SvOOK_off(sv)		(SvOOK(sv) && sv_backoff(sv))
 
 #define SvFAKE(sv)		(SvFLAGS(sv) & SVf_FAKE)
 #define SvFAKE_on(sv)		(SvFLAGS(sv) |= SVf_FAKE)
@@ -715,14 +664,16 @@ and leaves the UTF-8 status as it was.
 
 #define SvTHINKFIRST(sv)	(SvFLAGS(sv) & SVf_THINKFIRST)
 
-#define SvPADBUSY(sv)		(SvFLAGS(sv) & SVs_PADBUSY)
+#define SvPADSTALE(sv)		(SvFLAGS(sv) & SVs_PADSTALE)
+#define SvPADSTALE_on(sv)	(SvFLAGS(sv) |= SVs_PADSTALE)
+#define SvPADSTALE_off(sv)	(SvFLAGS(sv) &= ~SVs_PADSTALE)
 
 #define SvPADTMP(sv)		(SvFLAGS(sv) & SVs_PADTMP)
-#define SvPADTMP_on(sv)		(SvFLAGS(sv) |= SVs_PADTMP|SVs_PADBUSY)
+#define SvPADTMP_on(sv)		(SvFLAGS(sv) |= SVs_PADTMP)
 #define SvPADTMP_off(sv)	(SvFLAGS(sv) &= ~SVs_PADTMP)
 
 #define SvPADMY(sv)		(SvFLAGS(sv) & SVs_PADMY)
-#define SvPADMY_on(sv)		(SvFLAGS(sv) |= SVs_PADMY|SVs_PADBUSY)
+#define SvPADMY_on(sv)		(SvFLAGS(sv) |= SVs_PADMY)
 
 #define SvTEMP(sv)		(SvFLAGS(sv) & SVs_TEMP)
 #define SvTEMP_on(sv)		(SvFLAGS(sv) |= SVs_TEMP)
@@ -768,22 +719,17 @@ and leaves the UTF-8 status as it was.
 #define SvRVx(sv) SvRV(sv)
 
 #define SvIVX(sv) ((XPVIV*)  SvANY(sv))->xiv_iv
+#define SvIVXx(sv) SvIVX(sv)
 #define SvUVX(sv) ((XPVUV*)  SvANY(sv))->xuv_uv
+#define SvUVXx(sv) SvUVX(sv)
 #define SvNVX(sv)  ((XPVNV*)SvANY(sv))->xnv_nv
+#define SvNVXx(sv) SvNVX(sv)
 #define SvPVX(sv)  ((XPV*)  SvANY(sv))->xpv_pv
-/* Given that these two are new, there can't be any existing code using them
- *  as LVALUEs  */
-#define SvPVX_mutable(sv)	(0 + SvPVX(sv))
-#define SvPVX_const(sv)	((const char*) (0 + SvPVX(sv)))
+#define SvPVXx(sv) SvPVX(sv)
 #define SvCUR(sv) ((XPV*)  SvANY(sv))->xpv_cur
 #define SvLEN(sv) ((XPV*)  SvANY(sv))->xpv_len
-#define SvEND(sv)(((XPV*)  SvANY(sv))->xpv_pv + ((XPV*)SvANY(sv))->xpv_cur)
-
-#define SvIVXx(sv) SvIVX(sv)
-#define SvUVXx(sv) SvUVX(sv)
-#define SvNVXx(sv) SvNVX(sv)
-#define SvPVXx(sv) SvPVX(sv)
 #define SvLENx(sv) SvLEN(sv)
+#define SvEND(sv)(((XPV*)  SvANY(sv))->xpv_pv + ((XPV*)SvANY(sv))->xpv_cur)
 #define SvENDx(sv) ((PL_Sv = (sv)), SvEND(PL_Sv))
 #define SvMAGIC(sv)	((XPVMG*)  SvANY(sv))->xmg_magic
 #define SvSTASH(sv)	((XPVMG*)  SvANY(sv))->xmg_stash
@@ -794,69 +740,24 @@ and leaves the UTF-8 status as it was.
 #define SvIV_please(sv) \
 	STMT_START {if (!SvIOKp(sv) && (SvNOK(sv) || SvPOK(sv))) \
 		(void) SvIV(sv); } STMT_END
-/* Put the asserts back at some point and figure out where they reveal bugs
-*/
 #define SvIV_set(sv, val) \
 	STMT_START { assert(SvTYPE(sv) == SVt_IV || SvTYPE(sv) >= SVt_PVIV); \
-		(((XPVIV*)  SvANY(sv))->xiv_iv = (val)); } STMT_END
+		(((XPVIV*)  SvANY(sv))->xiv_iv = val); } STMT_END
 #define SvNV_set(sv, val) \
 	STMT_START { assert(SvTYPE(sv) == SVt_NV || SvTYPE(sv) >= SVt_PVNV); \
-		(((XPVNV*)SvANY(sv))->xnv_nv = (val)); } STMT_END
-/* assert(SvTYPE(sv) >= SVt_PV); */
+		(((XPVNV*)  SvANY(sv))->xnv_nv = val); } STMT_END
 #define SvPV_set(sv, val) \
-	STMT_START { \
-		(((XPV*)  SvANY(sv))->xpv_pv = (val)); } STMT_END
-/* assert(SvTYPE(sv) == SVt_IV || SvTYPE(sv) >= SVt_PVIV); */
-#define SvUV_set(sv, val) \
-	STMT_START { \
-		(((XPVUV*)SvANY(sv))->xuv_uv = (val)); } STMT_END
-/* assert(SvTYPE(sv) >=  SVt_RV); */
-#define SvRV_set(sv, val) \
-        STMT_START { \
-                (((XRV*)SvANY(sv))->xrv_rv = (val)); } STMT_END
-/* assert(SvTYPE(sv) >= SVt_PVMG); */
-#define SvMAGIC_set(sv, val) \
-        STMT_START {  \
-                (((XPVMG*)SvANY(sv))->xmg_magic = (val)); } STMT_END
-/* assert(SvTYPE(sv) >= SVt_PVMG); */
-#define SvSTASH_set(sv, val) \
-        STMT_START { \
-                (((XPVMG*)  SvANY(sv))->xmg_stash = (val)); } STMT_END
-/* assert(SvTYPE(sv) >= SVt_PV); */
+	STMT_START { assert(SvTYPE(sv) >= SVt_PV); \
+		(((XPV*)  SvANY(sv))->xpv_pv = val); } STMT_END
 #define SvCUR_set(sv, val) \
-	STMT_START { \
-		(((XPV*)  SvANY(sv))->xpv_cur = (val)); } STMT_END
-/* assert(SvTYPE(sv) >= SVt_PV); */
+	STMT_START { assert(SvTYPE(sv) >= SVt_PV); \
+		(((XPV*)  SvANY(sv))->xpv_cur = val); } STMT_END
 #define SvLEN_set(sv, val) \
-	STMT_START { \
-		(((XPV*)  SvANY(sv))->xpv_len = (val)); } STMT_END
+	STMT_START { assert(SvTYPE(sv) >= SVt_PV); \
+		(((XPV*)  SvANY(sv))->xpv_len = val); } STMT_END
 #define SvEND_set(sv, val) \
 	STMT_START { assert(SvTYPE(sv) >= SVt_PV); \
-		(SvCUR(sv) = (val) - SvPVX(sv)); } STMT_END
-
-#define SvPV_renew(sv,n) \
-	STMT_START { SvLEN_set(sv, n); \
-		SvPV_set((sv), (MEM_WRAP_CHECK_(n,char)			\
-				(char*)saferealloc((Malloc_t)SvPVX(sv), \
-						   (MEM_SIZE)((n)))));  \
-		 } STMT_END
-
-#define SvPV_shrink_to_cur(sv) STMT_START { \
-		   const STRLEN _lEnGtH = SvCUR(sv) + 1; \
-		   SvPV_renew(sv, _lEnGtH); \
-		 } STMT_END
-
-#define SvPV_free(sv) \
-	STMT_START { assert(SvTYPE(sv) >= SVt_PV);	\
-		if (SvLEN(sv)) {			\
-		    if(SvOOK(sv)) {			\
-		      Safefree(SvPVX(sv) - SvIVX(sv));	\
-		      SvFLAGS(sv) &= ~SVf_OOK;		\
-		    } else {				\
-		      Safefree(SvPVX(sv));		\
-		    }					\
-		}					\
-	} STMT_END
+		(((XPV*)  SvANY(sv))->xpv_cur = val - SvPVX(sv)); } STMT_END
 
 #define BmRARE(sv)	((XPVBM*)  SvANY(sv))->xbm_rare
 #define BmUSEFUL(sv)	((XPVBM*)  SvANY(sv))->xbm_useful
@@ -1033,15 +934,6 @@ COW)
 Returns a boolean indicating whether the SV is Copy-On-Write shared hash key
 scalar.
 
-=for apidoc Am|void|sv_catpvn_nomg|SV* sv|const char* ptr|STRLEN len
-Like C<sv_catpvn> but doesn't process magic.
-
-=for apidoc Am|void|sv_setsv_nomg|SV* dsv|SV* ssv
-Like C<sv_setsv> but doesn't process magic.
-
-=for apidoc Am|void|sv_catsv_nomg|SV* dsv|SV* ssv
-Like C<sv_catsv> but doesn't process magic.
-
 =cut
 */
 
@@ -1053,54 +945,24 @@ Like C<sv_catsv> but doesn't process magic.
 /* ----*/
 
 #define SvPV(sv, lp) SvPV_flags(sv, lp, SV_GMAGIC)
-#define SvPV_const(sv, lp) SvPV_flags_const(sv, lp, SV_GMAGIC)
-#define SvPV_mutable(sv, lp) SvPV_flags_mutable(sv, lp, SV_GMAGIC)
 
 #define SvPV_flags(sv, lp, flags) \
     ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
      ? ((lp = SvCUR(sv)), SvPVX(sv)) : sv_2pv_flags(sv, &lp, flags))
-#define SvPV_flags_const(sv, lp, flags) \
-    ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
-     ? ((lp = SvCUR(sv)), SvPVX_const(sv)) : \
-     (const char*) sv_2pv_flags(sv, &lp, flags|SV_CONST_RETURN))
-#define SvPV_flags_const_nolen(sv, flags) \
-    ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
-     ? SvPVX_const(sv) : \
-     (const char*) sv_2pv_flags(sv, 0, flags|SV_CONST_RETURN))
-#define SvPV_flags_mutable(sv, lp, flags) \
-    ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
-     ? ((lp = SvCUR(sv)), SvPVX_mutable(sv)) : \
-     sv_2pv_flags(sv, &lp, flags|SV_MUTABLE_RETURN))
 
 #define SvPV_force(sv, lp) SvPV_force_flags(sv, lp, SV_GMAGIC)
-#define SvPV_force_nolen(sv) SvPV_force_flags_nolen(sv, SV_GMAGIC)
-#define SvPV_force_mutable(sv, lp) SvPV_force_flags_mutable(sv, lp, SV_GMAGIC)
 
 #define SvPV_force_nomg(sv, lp) SvPV_force_flags(sv, lp, 0)
-#define SvPV_force_nomg_nolen(sv) SvPV_force_flags_nolen(sv, 0)
 
 #define SvPV_force_flags(sv, lp, flags) \
     ((SvFLAGS(sv) & (SVf_POK|SVf_THINKFIRST)) == SVf_POK \
     ? ((lp = SvCUR(sv)), SvPVX(sv)) : sv_pvn_force_flags(sv, &lp, flags))
-#define SvPV_force_flags_nolen(sv, flags) \
-    ((SvFLAGS(sv) & (SVf_POK|SVf_THINKFIRST)) == SVf_POK \
-    ? SvPVX(sv) : sv_pvn_force_flags(sv, 0, flags))
-#define SvPV_force_flags_mutable(sv, lp, flags) \
-    ((SvFLAGS(sv) & (SVf_POK|SVf_THINKFIRST)) == SVf_POK \
-    ? ((lp = SvCUR(sv)), SvPVX_mutable(sv)) \
-     : sv_pvn_force_flags(sv, &lp, flags|SV_MUTABLE_RETURN))
 
 #define SvPV_nolen(sv) \
     ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
-     ? SvPVX(sv) : sv_2pv_flags(sv, 0, SV_GMAGIC))
-
-#define SvPV_nolen_const(sv) \
-    ((SvFLAGS(sv) & (SVf_POK)) == SVf_POK \
-     ? SvPVX_const(sv) : sv_2pv_flags(sv, 0, SV_GMAGIC|SV_CONST_RETURN))
+     ? SvPVX(sv) : sv_2pv_nolen(sv))
 
 #define SvPV_nomg(sv, lp) SvPV_flags(sv, lp, 0)
-#define SvPV_nomg_const(sv, lp) SvPV_flags_const(sv, lp, 0)
-#define SvPV_nomg_const_nolen(sv) SvPV_flags_const_nolen(sv, 0)
 
 /* ----*/
 
@@ -1115,7 +977,7 @@ Like C<sv_catsv> but doesn't process magic.
 
 #define SvPVutf8_nolen(sv) \
     ((SvFLAGS(sv) & (SVf_POK|SVf_UTF8)) == (SVf_POK|SVf_UTF8)\
-     ? SvPVX(sv) : sv_2pvutf8(sv, 0))
+     ? SvPVX(sv) : sv_2pvutf8_nolen(sv))
 
 /* ----*/
 
@@ -1125,11 +987,11 @@ Like C<sv_catsv> but doesn't process magic.
 
 #define SvPVbyte_force(sv, lp) \
     ((SvFLAGS(sv) & (SVf_POK|SVf_UTF8|SVf_THINKFIRST)) == (SVf_POK) \
-     ? ((lp = SvCUR(sv)), SvPVX(sv)) : sv_pvbyten_force(sv, &lp))
+     ? ((lp = SvCUR(sv)), SvPVX(sv)) : sv_pvbyte_force(sv, &lp))
 
 #define SvPVbyte_nolen(sv) \
     ((SvFLAGS(sv) & (SVf_POK|SVf_UTF8)) == (SVf_POK)\
-     ? SvPVX(sv) : sv_2pvbyte(sv, 0))
+     ? SvPVX(sv) : sv_2pvbyte_nolen(sv))
 
 
     
@@ -1144,16 +1006,12 @@ Like C<sv_catsv> but doesn't process magic.
 
 #if defined(__GNUC__) && !defined(PERL_GCC_BRACE_GROUPS_FORBIDDEN)
 
-#  define SvIVx(sv) ({SV *_sv = (SV*)(sv); SvIV(_sv); })
-#  define SvUVx(sv) ({SV *_sv = (SV*)(sv); SvUV(_sv); })
-#  define SvNVx(sv) ({SV *_sv = (SV*)(sv); SvNV(_sv); })
-#  define SvPVx(sv, lp) ({SV *_sv = (sv); SvPV(_sv, lp); })
-#  define SvPVx_const(sv, lp) ({SV *_sv = (sv); SvPV_const(_sv, lp); })
-#  define SvPVx_nolen(sv) ({SV *_sv = (sv); SvPV_nolen(_sv); })
-#  define SvPVx_nolen_const(sv) ({SV *_sv = (sv); SvPV_nolen_const(_sv); })
-#  define SvPVutf8x(sv, lp) ({SV *_sv = (sv); SvPVutf8(_sv, lp); })
-#  define SvPVbytex(sv, lp) ({SV *_sv = (sv); SvPVbyte(_sv, lp); })
-#  define SvPVbytex_nolen(sv) ({SV *_sv = (sv); SvPVbyte_nolen(_sv); })
+#  define SvIVx(sv) ({SV *nsv = (SV*)(sv); SvIV(nsv); })
+#  define SvUVx(sv) ({SV *nsv = (SV*)(sv); SvUV(nsv); })
+#  define SvNVx(sv) ({SV *nsv = (SV*)(sv); SvNV(nsv); })
+#  define SvPVx(sv, lp) ({SV *nsv = (sv); SvPV(nsv, lp); })
+#  define SvPVutf8x(sv, lp) ({SV *nsv = (sv); SvPVutf8(nsv, lp); })
+#  define SvPVbytex(sv, lp) ({SV *nsv = (sv); SvPVbyte(nsv, lp); })
 #  define SvTRUE(sv) (						\
     !sv								\
     ? 0								\
@@ -1170,36 +1028,20 @@ Like C<sv_catsv> but doesn't process magic.
 	    :   SvNOK(sv)					\
 		? SvNVX(sv) != 0.0				\
 		: sv_2bool(sv) )
-#  define SvTRUEx(sv) ({SV *_sv = (sv); SvTRUE(_sv); })
+#  define SvTRUEx(sv) ({SV *nsv = (sv); SvTRUE(nsv); })
 
 #else /* __GNUC__ */
 
-#  ifdef USE_5005THREADS
-#    define SvIVx(sv) sv_iv(sv)
-#    define SvUVx(sv) sv_uv(sv)
-#    define SvNVx(sv) sv_nv(sv)
-#    define SvPVx(sv, lp) sv_pvn(sv, &lp)
-#    define SvPVutf8x(sv, lp) sv_pvutf8n(sv, &lp)
-#    define SvPVbytex(sv, lp) sv_pvbyten(sv, &lp)
-#    define SvTRUE(sv) SvTRUEx(sv)
-#    define SvTRUEx(sv) sv_true(sv)
-
-#  else /* USE_5005THREADS */
-
 /* These inlined macros use globals, which will require a thread
  * declaration in user code, so we avoid them under threads */
 
-#    define SvIVx(sv) ((PL_Sv = (sv)), SvIV(PL_Sv))
-#    define SvUVx(sv) ((PL_Sv = (sv)), SvUV(PL_Sv))
-#    define SvNVx(sv) ((PL_Sv = (sv)), SvNV(PL_Sv))
-#    define SvPVx(sv, lp) ((PL_Sv = (sv)), SvPV(PL_Sv, lp))
-#    define SvPVx_const(sv, lp) ((PL_Sv = (sv)), SvPV_const(PL_Sv, lp))
-#    define SvPVx_nolen(sv) ((PL_Sv = (sv)), SvPV_nolen(PL_Sv))
-#    define SvPVx_nolen_const(sv) ((PL_Sv = (sv)), SvPV_nolen_const(PL_Sv))
-#    define SvPVutf8x(sv, lp) ((PL_Sv = (sv)), SvPVutf8(PL_Sv, lp))
-#    define SvPVbytex(sv, lp) ((PL_Sv = (sv)), SvPVbyte(PL_Sv, lp))
-#    define SvPVbytex_nolen(sv) ((PL_Sv = (sv)), SvPVbyte_nolen(PL_Sv))
-#    define SvTRUE(sv) (						\
+#  define SvIVx(sv) ((PL_Sv = (sv)), SvIV(PL_Sv))
+#  define SvUVx(sv) ((PL_Sv = (sv)), SvUV(PL_Sv))
+#  define SvNVx(sv) ((PL_Sv = (sv)), SvNV(PL_Sv))
+#  define SvPVx(sv, lp) ((PL_Sv = (sv)), SvPV(PL_Sv, lp))
+#  define SvPVutf8x(sv, lp) ((PL_Sv = (sv)), SvPVutf8(PL_Sv, lp))
+#  define SvPVbytex(sv, lp) ((PL_Sv = (sv)), SvPVbyte(PL_Sv, lp))
+#  define SvTRUE(sv) (						\
     !sv								\
     ? 0								\
     :    SvPOK(sv)						\
@@ -1214,24 +1056,45 @@ Like C<sv_catsv> but doesn't process magic.
 	    :   SvNOK(sv)					\
 		? SvNVX(sv) != 0.0				\
 		: sv_2bool(sv) )
-#    define SvTRUEx(sv) ((PL_Sv = (sv)), SvTRUE(PL_Sv))
-#  endif /* USE_5005THREADS */
+#  define SvTRUEx(sv) ((PL_Sv = (sv)), SvTRUE(PL_Sv))
 #endif /* __GNU__ */
 
 #define SvIsCOW(sv)		((SvFLAGS(sv) & (SVf_FAKE | SVf_READONLY)) == \
 				    (SVf_FAKE | SVf_READONLY))
 #define SvIsCOW_shared_hash(sv)	(SvIsCOW(sv) && SvLEN(sv) == 0)
 
-#define SvSHARED_HASH(sv) (0 + SvUVX(sv))
-
 /* flag values for sv_*_flags functions */
 #define SV_IMMEDIATE_UNREF	1
 #define SV_GMAGIC		2
-#define SV_COW_DROP_PV		4	/* Unused in Perl 5.8.x */
+#define SV_COW_DROP_PV		4
 #define SV_UTF8_NO_ENCODING	8
-#define SV_NOSTEAL		16
-#define SV_CONST_RETURN		32
-#define SV_MUTABLE_RETURN	64
+
+/* We are about to replace the SV's current value. So if it's copy on write
+   we need to normalise it. Use the SV_COW_DROP_PV flag hint to say that
+   the value is about to get thrown away, so drop the PV rather than go to
+   the effort of making a read-write copy only for it to get immediately
+   discarded.  */
+
+#define SV_CHECK_THINKFIRST_COW_DROP(sv) if (SvTHINKFIRST(sv)) \
+				    sv_force_normal_flags(sv, SV_COW_DROP_PV)
+
+#ifdef PERL_COPY_ON_WRITE
+#  define SvRELEASE_IVX(sv)   ((void)((SvFLAGS(sv) & (SVf_OOK|SVf_READONLY|SVf_FAKE)) \
+				&& Perl_sv_release_IVX(aTHX_ sv)))
+#  define SvIsCOW_normal(sv)	(SvIsCOW(sv) && SvLEN(sv))
+
+#define CAN_COW_MASK	(SVs_OBJECT|SVs_GMG|SVs_SMG|SVs_RMG|SVf_IOK|SVf_NOK| \
+			 SVf_POK|SVf_ROK|SVp_IOK|SVp_NOK|SVp_POK|SVf_FAKE| \
+			 SVf_OOK|SVf_BREAK|SVf_READONLY|SVf_AMAGIC)
+#define CAN_COW_FLAGS	(SVp_POK|SVf_POK)
+
+#else
+#  define SvRELEASE_IVX(sv)   ((void)SvOOK_off(sv))
+#endif /* PERL_COPY_ON_WRITE */
+
+#define SV_CHECK_THINKFIRST(sv) if (SvTHINKFIRST(sv)) \
+				    sv_force_normal_flags(sv, 0)
+
 
 /* all these 'functions' are now just macros */
 
@@ -1300,7 +1163,7 @@ ssv. May evaluate arguments more than once.
 Like C<SvSetSV>, but does any set magic required afterwards.
 
 =for apidoc Am|void|SvSetMagicSV_nosteal|SV* dsv|SV* ssv
-Like C<SvSetSV_nosteal>, but does any set magic required afterwards.
+Like C<SvSetMagicSV>, but does any set magic required afterwards.
 
 =for apidoc Am|void|SvSHARE|SV* sv
 Arranges for sv to be shared between threads if a suitable module
@@ -1342,7 +1205,10 @@ Returns a pointer to the character buffer.
 #define SvSetSV_nosteal_and(dst,src,finally) \
 	STMT_START {					\
 	    if ((dst) != (src)) {			\
-		sv_setsv_flags(dst, src, SV_GMAGIC | SV_NOSTEAL);	\
+		U32 tMpF = SvFLAGS(src) & SVs_TEMP;	\
+		SvTEMP_off(src);			\
+		sv_setsv(dst, src);			\
+		SvFLAGS(src) |= tMpF;			\
 		finally;				\
 	    }						\
 	} STMT_END
@@ -1371,8 +1237,6 @@ Returns a pointer to the character buffer.
 #define isGV(sv) (SvTYPE(sv) == SVt_PVGV)
 
 #define SvGROW(sv,len) (SvLEN(sv) < (len) ? sv_grow(sv,len) : SvPVX(sv))
-#define SvGROW_mutable(sv,len) \
-    (SvLEN(sv) < (len) ? sv_grow(sv,len) : SvPVX_mutable(sv))
 #define Sv_Grow sv_grow
 
 #define CLONEf_COPY_STACKS 1
@@ -1385,5 +1249,3 @@ struct clone_params {
   UV  flags;
   PerlInterpreter *proto_perl;
 };
-
-#define SV_CHECK_THINKFIRST(sv) if (SvTHINKFIRST(sv)) sv_force_normal(sv)
