@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-$VERSION = '1.02_02';
+$VERSION = '1.02';
 
 BEGIN {
   push @INC, './lib';
@@ -62,6 +62,7 @@ my $tree = {
        	'pack'		=> [ 5.008, DEFAULT_OFF],
        	'unpack'	=> [ 5.008, DEFAULT_OFF],
        	'threads'	=> [ 5.008, DEFAULT_OFF],
+	'assertions'    => [ 5.009, DEFAULT_OFF],
 
        	 #'default'	=> [ 5.008, DEFAULT_ON ],
   	}],
@@ -252,13 +253,10 @@ if (@ARGV && $ARGV[0] eq "tree")
 unlink "warnings.h";
 unlink "lib/warnings.pm";
 open(WARN, ">warnings.h") || die "Can't create warnings.h: $!\n";
-binmode WARN;
 open(PM, ">lib/warnings.pm") || die "Can't create lib/warnings.pm: $!\n";
-binmode PM;
 
 print WARN <<'EOM' ;
-/* -*- buffer-read-only: t -*-
-   !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
+/* !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
    This file is built by warnings.pl
    Any changes made here will be lost!
 */
@@ -276,15 +274,12 @@ print WARN <<'EOM' ;
 #define G_WARN_ONCE		8	/* set if 'once' ever enabled */
 #define G_WARN_ALL_MASK		(G_WARN_ALL_ON|G_WARN_ALL_OFF)
 
-#define pWARN_STD		NULL
-#define pWARN_ALL		(((SV*)0)+1)	/* use warnings 'all' */
-#define pWARN_NONE		(((SV*)0)+2)	/* no  warnings 'all' */
+#define pWARN_STD		Nullsv
+#define pWARN_ALL		(Nullsv+1)	/* use warnings 'all' */
+#define pWARN_NONE		(Nullsv+2)	/* no  warnings 'all' */
 
 #define specialWARN(x)		((x) == pWARN_STD || (x) == pWARN_ALL ||	\
 				 (x) == pWARN_NONE)
-
-/* if PL_warnhook is set to this value, then warnings die */
-#define PERL_WARNHOOK_FATAL	(((SV*)0) + 1)
 EOM
 
 my $offset = 0 ;
@@ -328,23 +323,69 @@ print WARN <<'EOM';
 #define isLEXWARN_on 	(PL_curcop->cop_warnings != pWARN_STD)
 #define isLEXWARN_off	(PL_curcop->cop_warnings == pWARN_STD)
 #define isWARN_ONCE	(PL_dowarn & (G_WARN_ON|G_WARN_ONCE))
-#define isWARN_on(c,x)	(IsSet(SvPVX_const(c), 2*(x)))
-#define isWARNf_on(c,x)	(IsSet(SvPVX_const(c), 2*(x)+1))
+#define isWARN_on(c,x)	(IsSet(SvPVX(c), 2*(x)))
+#define isWARNf_on(c,x)	(IsSet(SvPVX(c), 2*(x)+1))
 
-#define ckWARN(w)		Perl_ckwarn(aTHX_ packWARN(w))
-#define ckWARN2(w1,w2)		Perl_ckwarn(aTHX_ packWARN2(w1,w2))
-#define ckWARN3(w1,w2,w3)	Perl_ckwarn(aTHX_ packWARN3(w1,w2,w3))
-#define ckWARN4(w1,w2,w3,w4)	Perl_ckwarn(aTHX_ packWARN4(w1,w2,w3,w4))
+#define ckWARN(x)							\
+	( (isLEXWARN_on && PL_curcop->cop_warnings != pWARN_NONE &&	\
+	      (PL_curcop->cop_warnings == pWARN_ALL ||			\
+	       isWARN_on(PL_curcop->cop_warnings, x) ) )		\
+	  || (isLEXWARN_off && PL_dowarn & G_WARN_ON) )
 
-#define ckWARN_d(w)		Perl_ckwarn_d(aTHX_ packWARN(w))
-#define ckWARN2_d(w1,w2)	Perl_ckwarn_d(aTHX_ packWARN2(w1,w2))
-#define ckWARN3_d(w1,w2,w3)	Perl_ckwarn_d(aTHX_ packWARN3(w1,w2,w3))
-#define ckWARN4_d(w1,w2,w3,w4)	Perl_ckwarn_d(aTHX_ packWARN4(w1,w2,w3,w4))
+#define ckWARN2(x,y)							\
+	  ( (isLEXWARN_on && PL_curcop->cop_warnings != pWARN_NONE &&	\
+	      (PL_curcop->cop_warnings == pWARN_ALL ||			\
+	        isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, y) ) ) 		\
+	    ||	(isLEXWARN_off && PL_dowarn & G_WARN_ON) )
 
-#define packWARN(a)		(a                                      )
-#define packWARN2(a,b)		((a) | ((b)<<8)                         )
-#define packWARN3(a,b,c)	((a) | ((b)<<8) | ((c)<<16)             )
-#define packWARN4(a,b,c,d)	((a) | ((b)<<8) | ((c)<<16) | ((d) <<24))
+#define ckWARN3(x,y,z)							\
+	  ( (isLEXWARN_on && PL_curcop->cop_warnings != pWARN_NONE &&	\
+	      (PL_curcop->cop_warnings == pWARN_ALL ||			\
+	        isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, y)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, z) ) ) 		\
+	    ||	(isLEXWARN_off && PL_dowarn & G_WARN_ON) )
+
+#define ckWARN4(x,y,z,t)						\
+	  ( (isLEXWARN_on && PL_curcop->cop_warnings != pWARN_NONE &&	\
+	      (PL_curcop->cop_warnings == pWARN_ALL ||			\
+	        isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, y)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, z)  ||		\
+	        isWARN_on(PL_curcop->cop_warnings, t) ) ) 		\
+	    ||	(isLEXWARN_off && PL_dowarn & G_WARN_ON) )
+
+#define ckWARN_d(x)							\
+	  (isLEXWARN_off || PL_curcop->cop_warnings == pWARN_ALL ||	\
+	     (PL_curcop->cop_warnings != pWARN_NONE &&			\
+	      isWARN_on(PL_curcop->cop_warnings, x) ) )
+
+#define ckWARN2_d(x,y)							\
+	  (isLEXWARN_off || PL_curcop->cop_warnings == pWARN_ALL ||	\
+	     (PL_curcop->cop_warnings != pWARN_NONE &&			\
+	        (isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, y) ) ) )
+
+#define ckWARN3_d(x,y,z)						\
+	  (isLEXWARN_off || PL_curcop->cop_warnings == pWARN_ALL ||	\
+	     (PL_curcop->cop_warnings != pWARN_NONE &&			\
+	        (isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, y)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, z) ) ) )
+
+#define ckWARN4_d(x,y,z,t)						\
+	  (isLEXWARN_off || PL_curcop->cop_warnings == pWARN_ALL ||	\
+	     (PL_curcop->cop_warnings != pWARN_NONE &&			\
+	        (isWARN_on(PL_curcop->cop_warnings, x)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, y)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, z)  ||		\
+	         isWARN_on(PL_curcop->cop_warnings, t) ) ) )
+
+#define packWARN(a)		(a                                 )
+#define packWARN2(a,b)		((a) | (b)<<8                      )
+#define packWARN3(a,b,c)	((a) | (b)<<8 | (c) <<16           )
+#define packWARN4(a,b,c,d)	((a) | (b)<<8 | (c) <<16 | (d) <<24)
 
 #define unpackWARN1(x)		((x)        & 0xFF)
 #define unpackWARN2(x)		(((x) >>8)  & 0xFF)
@@ -360,7 +401,7 @@ print WARN <<'EOM';
 	      isWARNf_on(PL_curcop->cop_warnings, unpackWARN4(x))))
 
 /* end of file warnings.h */
-/* ex: set ro: */
+
 EOM
 
 close WARN ;
@@ -373,7 +414,7 @@ while (<DATA>) {
 #$list{'all'} = [ $offset .. 8 * ($warn_size/2) - 1 ] ;
 
 $last_ver = 0;
-print PM "our %Offsets = (\n" ;
+print PM "our %Offsets : unique = (\n" ;
 foreach my $k (sort { $a <=> $b } keys %ValueToName) {
     my ($name, $version) = @{ $ValueToName{$k} };
     $name = lc $name;
@@ -389,7 +430,7 @@ foreach my $k (sort { $a <=> $b } keys %ValueToName) {
 
 print PM "  );\n\n" ;
 
-print PM "our %Bits = (\n" ;
+print PM "our %Bits : unique = (\n" ;
 foreach $k (sort keys  %list) {
 
     my $v = $list{$k} ;
@@ -403,7 +444,7 @@ foreach $k (sort keys  %list) {
 
 print PM "  );\n\n" ;
 
-print PM "our %DeadBits = (\n" ;
+print PM "our %DeadBits : unique = (\n" ;
 foreach $k (sort keys  %list) {
 
     my $v = $list{$k} ;
@@ -423,11 +464,10 @@ while (<DATA>) {
     print PM $_ ;
 }
 
-print PM "# ex: set ro:\n";
 close PM ;
 
 __END__
-# -*- buffer-read-only: t -*-
+
 # !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
 # This file was created by warnings.pl
 # Any changes made here will be lost.
@@ -435,7 +475,7 @@ __END__
 
 package warnings;
 
-our $VERSION = '1.05_01';
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -568,7 +608,6 @@ $All = "" ; vec($All, $Offsets{'all'}, 2) = 3 ;
 
 sub Croaker
 {
-    require Carp::Heavy; # this initializes %CarpInternal
     delete $Carp::CarpInternal{'warnings'};
     Carp::croak(@_);
 }
@@ -671,8 +710,6 @@ sub unimport
     ${^WARNING_BITS} = $mask ;
 }
 
-my %builtin_type; @builtin_type{qw(SCALAR ARRAY HASH CODE REF GLOB LVALUE Regexp)} = ();
-
 sub __chk
 {
     my $category ;
@@ -682,10 +719,10 @@ sub __chk
     if (@_) {
         # check the category supplied.
         $category = shift ;
-        if (my $type = ref $category) {
-            Croaker("not an object")
-                if exists $builtin_type{$type};
-	    $category = $type;
+        if (ref $category) {
+            Croaker ("not an object")
+                if $category !~ /^([^=]+)=/ ;
+	    $category = $1 ;
             $isobj = 1 ;
         }
         $offset = $Offsets{$category};
@@ -710,17 +747,18 @@ sub __chk
 	$i -= 2 ;
     }
     else {
-        for ($i = 2 ; $pkg = (caller($i))[0] ; ++ $i) {
-            last if $pkg ne $this_pkg ;
-        }
-        $i = 2
-            if !$pkg || $pkg eq $this_pkg ;
+        $i = _error_loc(); # see where Carp will allocate the error
     }
 
     my $callers_bitmask = (caller($i))[9] ;
     return ($callers_bitmask, $offset, $i) ;
 }
 
+sub _error_loc {
+    require Carp::Heavy;
+    goto &Carp::short_error_loc; # don't introduce another stack frame
+}                                                             
+
 sub enabled
 {
     Croaker("Usage: warnings::enabled([category])")
